@@ -21,15 +21,15 @@ import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 
 import org.kie.workbench.common.dmn.api.definition.HasComponentWidths;
-import org.kie.workbench.common.dmn.api.definition.v1_1.BusinessKnowledgeModel;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DRGElement;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Decision;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DecisionService;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItemPrimary;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InputData;
-import org.kie.workbench.common.dmn.api.definition.v1_1.KnowledgeRequirement;
-import org.kie.workbench.common.dmn.api.definition.v1_1.KnowledgeSource;
+import org.kie.workbench.common.dmn.api.definition.model.BusinessKnowledgeModel;
+import org.kie.workbench.common.dmn.api.definition.model.DRGElement;
+import org.kie.workbench.common.dmn.api.definition.model.Decision;
+import org.kie.workbench.common.dmn.api.definition.model.DecisionService;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItemPrimary;
+import org.kie.workbench.common.dmn.api.definition.model.InputData;
+import org.kie.workbench.common.dmn.api.definition.model.KnowledgeRequirement;
+import org.kie.workbench.common.dmn.api.definition.model.KnowledgeSource;
 import org.kie.workbench.common.dmn.api.property.background.BackgroundSet;
 import org.kie.workbench.common.dmn.api.property.dimensions.GeneralRectangleDimensionsSet;
 import org.kie.workbench.common.dmn.api.property.dmn.AllowedAnswers;
@@ -45,7 +45,10 @@ import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.relationship.Child;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
-public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.Decision, org.kie.workbench.common.dmn.api.definition.v1_1.Decision> {
+import static org.kie.workbench.common.dmn.backend.definition.v1_1.HrefBuilder.getHref;
+import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionId;
+
+public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.Decision, org.kie.workbench.common.dmn.api.definition.model.Decision> {
 
     private FactoryManager factoryManager;
 
@@ -59,11 +62,11 @@ public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.De
                                                final BiConsumer<String, HasComponentWidths> hasComponentWidthsConsumer) {
         @SuppressWarnings("unchecked")
         final Node<View<Decision>, ?> node = (Node<View<Decision>, ?>) factoryManager.newElement(dmn.getId(),
-                                                                                                 Decision.class).asNode();
+                                                                                                 getDefinitionId(Decision.class)).asNode();
         final Id id = new Id(dmn.getId());
         final Description description = DescriptionPropertyConverter.wbFromDMN(dmn.getDescription());
         final Name name = new Name(dmn.getName());
-        final InformationItemPrimary informationItem = InformationItemPrimaryPropertyConverter.wbFromDMN(dmn.getVariable());
+        final InformationItemPrimary informationItem = InformationItemPrimaryPropertyConverter.wbFromDMN(dmn.getVariable(), dmn);
         final Expression expression = ExpressionPropertyConverter.wbFromDMN(dmn.getExpression(),
                                                                             hasComponentWidthsConsumer);
         final Decision decision = new Decision(id,
@@ -87,6 +90,7 @@ public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.De
             expression.setParent(decision);
         }
 
+        DMNExternalLinksToExtensionElements.loadExternalLinksFromExtensionElements(dmn, decision);
         return node;
     }
 
@@ -98,7 +102,7 @@ public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.De
         d.setId(source.getId().getValue());
         d.setDescription(DescriptionPropertyConverter.dmnFromWB(source.getDescription()));
         d.setName(source.getName().getValue());
-        final org.kie.dmn.model.api.InformationItem variable = InformationItemPrimaryPropertyConverter.dmnFromWB(source.getVariable());
+        final org.kie.dmn.model.api.InformationItem variable = InformationItemPrimaryPropertyConverter.dmnFromWB(source.getVariable(), source);
         if (variable != null) {
             variable.setParent(d);
         }
@@ -123,28 +127,28 @@ public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.De
                         final org.kie.dmn.model.api.InformationRequirement iReq = new org.kie.dmn.model.v1_2.TInformationRequirement();
                         iReq.setId(e.getUUID());
                         final org.kie.dmn.model.api.DMNElementReference ri = new org.kie.dmn.model.v1_2.TDMNElementReference();
-                        ri.setHref(new StringBuilder("#").append(drgElement.getId().getValue()).toString());
+                        ri.setHref(getHref(drgElement));
                         iReq.setRequiredDecision(ri);
                         d.getInformationRequirement().add(iReq);
                     } else if (drgElement instanceof BusinessKnowledgeModel) {
                         final org.kie.dmn.model.api.KnowledgeRequirement iReq = new org.kie.dmn.model.v1_2.TKnowledgeRequirement();
                         iReq.setId(e.getUUID());
                         final org.kie.dmn.model.api.DMNElementReference ri = new org.kie.dmn.model.v1_2.TDMNElementReference();
-                        ri.setHref(new StringBuilder("#").append(drgElement.getId().getValue()).toString());
+                        ri.setHref(getHref(drgElement));
                         iReq.setRequiredKnowledge(ri);
                         d.getKnowledgeRequirement().add(iReq);
                     } else if (drgElement instanceof KnowledgeSource) {
                         final org.kie.dmn.model.api.AuthorityRequirement iReq = new org.kie.dmn.model.v1_2.TAuthorityRequirement();
                         iReq.setId(e.getUUID());
                         final org.kie.dmn.model.api.DMNElementReference ri = new org.kie.dmn.model.v1_2.TDMNElementReference();
-                        ri.setHref(new StringBuilder("#").append(drgElement.getId().getValue()).toString());
+                        ri.setHref(getHref(drgElement));
                         iReq.setRequiredAuthority(ri);
                         d.getAuthorityRequirement().add(iReq);
                     } else if (drgElement instanceof InputData) {
                         final org.kie.dmn.model.api.InformationRequirement iReq = new org.kie.dmn.model.v1_2.TInformationRequirement();
                         iReq.setId(e.getUUID());
                         final org.kie.dmn.model.api.DMNElementReference ri = new org.kie.dmn.model.v1_2.TDMNElementReference();
-                        ri.setHref(new StringBuilder("#").append(drgElement.getId().getValue()).toString());
+                        ri.setHref(getHref(drgElement));
                         iReq.setRequiredInput(ri);
                         d.getInformationRequirement().add(iReq);
                     } else if (drgElement instanceof DecisionService) {
@@ -154,7 +158,7 @@ public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.De
                             final org.kie.dmn.model.api.KnowledgeRequirement iReq = new org.kie.dmn.model.v1_2.TKnowledgeRequirement();
                             iReq.setId(e.getUUID());
                             final org.kie.dmn.model.api.DMNElementReference ri = new org.kie.dmn.model.v1_2.TDMNElementReference();
-                            ri.setHref(new StringBuilder("#").append(drgElement.getId().getValue()).toString());
+                            ri.setHref(getHref(drgElement));
                             iReq.setRequiredKnowledge(ri);
                             d.getKnowledgeRequirement().add(iReq);
                         } else {
@@ -166,6 +170,9 @@ public class DecisionConverter implements NodeConverter<org.kie.dmn.model.api.De
                 }
             }
         }
+
+        DMNExternalLinksToExtensionElements.loadExternalLinksIntoExtensionElements(source, d);
+
         return d;
     }
 }
