@@ -18,6 +18,8 @@ package org.kie.workbench.common.dmn.client.commands.general;
 
 import java.util.Optional;
 
+import javax.enterprise.event.Event;
+
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.dom.client.Style;
 import com.google.gwt.user.client.ui.Widget;
@@ -25,22 +27,17 @@ import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
+import org.kie.workbench.common.stunner.client.lienzo.canvas.LienzoCanvas;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.AbstractSessionPresenter;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.Layer;
 import org.kie.workbench.common.stunner.core.client.canvas.command.AbstractCanvasGraphCommand;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientSession;
-import org.kie.workbench.common.stunner.core.command.CommandResult;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
-import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
-import org.kie.workbench.common.stunner.core.graph.command.GraphCommandResultBuilder;
-import org.kie.workbench.common.stunner.core.graph.command.impl.AbstractGraphCommand;
-import org.kie.workbench.common.stunner.core.rule.RuleViolation;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.client.workbench.widgets.listbar.ResizeFlowPanel;
 
 public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
@@ -48,27 +45,34 @@ public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
     static final NoOperationGraphCommand NOP_GRAPH_COMMAND = new NoOperationGraphCommand();
 
     protected final ExpressionEditorView.Presenter editor;
-    protected final SessionPresenter<AbstractClientFullSession, ?, Diagram> presenter;
+    protected final SessionPresenter<? extends ClientSession, ?, Diagram> presenter;
     protected final SessionManager sessionManager;
     protected final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
+    protected final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent;
+
     protected final String nodeUUID;
     protected final HasExpression hasExpression;
     protected final Optional<HasName> hasName;
+    protected final boolean isOnlyVisualChangeAllowed;
 
     public BaseNavigateCommand(final ExpressionEditorView.Presenter editor,
-                               final SessionPresenter<AbstractClientFullSession, ?, Diagram> presenter,
+                               final SessionPresenter<? extends ClientSession, ?, Diagram> presenter,
                                final SessionManager sessionManager,
                                final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                               final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
                                final String nodeUUID,
                                final HasExpression hasExpression,
-                               final Optional<HasName> hasName) {
+                               final Optional<HasName> hasName,
+                               final boolean isOnlyVisualChangeAllowed) {
         this.editor = editor;
         this.presenter = presenter;
         this.sessionManager = sessionManager;
         this.sessionCommandManager = sessionCommandManager;
+        this.refreshFormPropertiesEvent = refreshFormPropertiesEvent;
         this.nodeUUID = nodeUUID;
         this.hasExpression = hasExpression;
         this.hasName = hasName;
+        this.isOnlyVisualChangeAllowed = isOnlyVisualChangeAllowed;
     }
 
     protected void navigateToExpressionEditor(final HasExpression hasExpression,
@@ -78,9 +82,11 @@ public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
                                                                             presenter,
                                                                             sessionManager,
                                                                             sessionCommandManager,
+                                                                            refreshFormPropertiesEvent,
                                                                             nodeUUID,
                                                                             hasExpression,
-                                                                            hasName));
+                                                                            hasName,
+                                                                            isOnlyVisualChangeAllowed));
     }
 
     protected void navigateToDRGEditor(final HasExpression hasExpression,
@@ -90,9 +96,11 @@ public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
                                                                      presenter,
                                                                      sessionManager,
                                                                      sessionCommandManager,
+                                                                     refreshFormPropertiesEvent,
                                                                      nodeUUID,
                                                                      hasExpression,
-                                                                     hasName));
+                                                                     hasName,
+                                                                     isOnlyVisualChangeAllowed));
     }
 
     protected void enableHandlers(final boolean enabled) {
@@ -100,20 +108,18 @@ public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
         if (handler == null) {
             return;
         }
-        final Layer layer = handler.getCanvas().getLayer();
+        final LienzoCanvas canvas = (LienzoCanvas) handler.getCanvas();
         if (enabled) {
-            layer.enableHandlers();
-            ((AbstractClientSession) sessionManager.getCurrentSession()).resume();
+            canvas.enableHandlers();
         } else {
-            layer.disableHandlers();
-            ((AbstractClientSession) sessionManager.getCurrentSession()).pause();
+            canvas.disableHandlers();
         }
     }
 
     protected void addExpressionEditorToCanvasWidget() {
         final ResizeFlowPanel container = wrapElementForErrai1090();
         presenter.getView().setCanvasWidget(container);
-        presenter.getView().setContentScrollType(SessionPresenter.View.ScrollType.CUSTOM);
+        editor.getView().setFocus();
 
         Scheduler.get().scheduleDeferred(container::onResize);
     }
@@ -143,7 +149,6 @@ public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
 
     protected void addDRGEditorToCanvasWidget() {
         presenter.getView().setCanvasWidget(((AbstractSessionPresenter) presenter).getDisplayer().getView());
-        presenter.getView().setContentScrollType(SessionPresenter.View.ScrollType.AUTO);
     }
 
     protected void hidePaletteWidget(final boolean hidden) {
@@ -153,22 +158,4 @@ public abstract class BaseNavigateCommand extends AbstractCanvasGraphCommand {
     private CanvasHandler getCanvasHandler() {
         return null != sessionManager.getCurrentSession() ? sessionManager.getCurrentSession().getCanvasHandler() : null;
     }
-
-    public static class NoOperationGraphCommand extends AbstractGraphCommand {
-
-        @Override
-        protected CommandResult<RuleViolation> check(final GraphCommandExecutionContext context) {
-            return GraphCommandResultBuilder.SUCCESS;
-        }
-
-        @Override
-        public CommandResult<RuleViolation> execute(final GraphCommandExecutionContext context) {
-            return GraphCommandResultBuilder.SUCCESS;
-        }
-
-        @Override
-        public CommandResult<RuleViolation> undo(final GraphCommandExecutionContext context) {
-            return GraphCommandResultBuilder.SUCCESS;
-        }
-    }
 }
