@@ -23,23 +23,25 @@ import java.util.stream.IntStream;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.List;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Relation;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.List;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Relation;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.selections.impl.RowSelectionStrategy;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Mockito.doReturn;
+import static org.junit.Assert.assertNull;
+import static org.kie.workbench.common.dmn.client.widgets.grid.model.BaseHasDynamicHeightCell.DEFAULT_HEIGHT;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class RelationUIModelMapperTest {
@@ -67,38 +69,39 @@ public class RelationUIModelMapperTest {
     @Before
     public void setup() {
         this.uiModel = new BaseGridData();
-        this.uiModel.appendRow(new DMNGridRow());
-        this.uiModel.appendRow(new DMNGridRow());
+        this.uiModel.appendRow(new BaseGridRow());
+        this.uiModel.appendRow(new BaseGridRow());
         this.uiModel.appendColumn(uiRowNumberColumn);
         this.uiModel.appendColumn(uiRelationColumn1);
         this.uiModel.appendColumn(uiRelationColumn2);
-        doReturn(0).when(uiRowNumberColumn).getIndex();
-        doReturn(1).when(uiRelationColumn1).getIndex();
-        doReturn(2).when(uiRelationColumn2).getIndex();
+        when(uiRowNumberColumn.getIndex()).thenReturn(0);
+        when(uiRelationColumn1.getIndex()).thenReturn(1);
+        when(uiRelationColumn2.getIndex()).thenReturn(2);
 
         this.relation = new Relation();
         this.relation.getColumn().add(new InformationItem());
         this.relation.getColumn().add(new InformationItem());
         this.relation.getRow().add(new List() {{
             getExpression().add(new LiteralExpression() {{
-                setText("le(1,0)");
+                getText().setValue("le(1,0)");
             }});
             getExpression().add(new LiteralExpression() {{
-                setText("le(2,0)");
+                getText().setValue("le(2,0)");
             }});
         }});
         this.relation.getRow().add(new List() {{
             getExpression().add(new LiteralExpression() {{
-                setText("le(1,1)");
+                getText().setValue("le(1,1)");
             }});
             getExpression().add(new LiteralExpression() {{
-                setText("le(2,1)");
+                getText().setValue("le(2,1)");
             }});
         }});
 
         this.mapper = new RelationUIModelMapper(() -> uiModel,
                                                 () -> Optional.of(relation),
-                                                listSelector);
+                                                listSelector,
+                                                DEFAULT_HEIGHT);
         this.cellValueSupplier = Optional::empty;
     }
 
@@ -152,6 +155,25 @@ public class RelationUIModelMapperTest {
         assertThat(uiModel.getCell(1, 2)).isInstanceOf(RelationGridCell.class);
     }
 
+    @Test
+    public void testToDMNModelLiteralExpressionsNullValue() {
+        cellValueSupplier = () -> Optional.of(new BaseGridCellValue<>(null));
+        for (int uiRowIndex = 0; uiRowIndex < uiModel.getRowCount(); uiRowIndex++) {
+            for (int uiColumnIndex = 1; uiColumnIndex < uiModel.getColumnCount(); uiColumnIndex++) {
+                mapper.toDMNModel(uiRowIndex,
+                                  uiColumnIndex,
+                                  cellValueSupplier);
+                final LiteralExpression le = (LiteralExpression) relation
+                        .getRow()
+                        .get(uiRowIndex)
+                        .getExpression()
+                        .get(uiColumnIndex - RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
+
+                assertNull(le.getText().getValue());
+            }
+        }
+    }
+
     @Test
     public void testToDMNModelLiteralExpressionsEmptyValue() {
         for (int uiRowIndex = 0; uiRowIndex < uiModel.getRowCount(); uiRowIndex++) {
@@ -166,7 +188,7 @@ public class RelationUIModelMapperTest {
                         .get(uiColumnIndex - RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
 
                 assertEquals("",
-                             le.getText());
+                             le.getText().getValue());
             }
         }
     }
@@ -187,7 +209,7 @@ public class RelationUIModelMapperTest {
                         .get(uiColumnIndex - RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
 
                 assertEquals(value,
-                             le.getText());
+                             le.getText().getValue());
             }
         }
     }
