@@ -19,19 +19,24 @@ package org.kie.workbench.common.dmn.client.editors.types.listview;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import elemental2.dom.Element;
 import elemental2.dom.HTMLElement;
+import elemental2.dom.NodeList;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.ItemDefinition;
+import org.kie.workbench.common.dmn.api.definition.model.ItemDefinition;
+import org.kie.workbench.common.dmn.client.editors.types.DataTypeChangedEvent;
 import org.kie.workbench.common.dmn.client.editors.types.common.DataType;
 import org.kie.workbench.common.dmn.client.editors.types.common.DataTypeManager;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.SmallSwitchComponent;
 import org.kie.workbench.common.dmn.client.editors.types.listview.confirmation.DataTypeConfirmation;
 import org.kie.workbench.common.dmn.client.editors.types.listview.constraint.DataTypeConstraint;
+import org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListComponent;
 import org.kie.workbench.common.dmn.client.editors.types.listview.validation.DataTypeNameFormatValidator;
 import org.kie.workbench.common.dmn.client.editors.types.persistence.ItemDefinitionStore;
 import org.mockito.ArgumentCaptor;
@@ -48,6 +53,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.BOOLEAN;
+import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.CONTEXT;
 import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.STRING;
 import static org.kie.workbench.common.dmn.client.editors.types.persistence.CreationType.ABOVE;
 import static org.kie.workbench.common.dmn.client.editors.types.persistence.CreationType.BELOW;
@@ -97,6 +103,9 @@ public class DataTypeListItemTest {
     @Mock
     private DataTypeNameFormatValidator nameFormatValidator;
 
+    @Mock
+    private EventSourceMock<DataTypeChangedEvent> dataTypeChangedEvent;
+
     @Captor
     private ArgumentCaptor<DataTypeEditModeToggleEvent> eventArgumentCaptor;
 
@@ -110,27 +119,26 @@ public class DataTypeListItemTest {
     public void setup() {
 
         dataTypeManager = spy(new DataTypeManager(null, null, itemDefinitionStore, null, null, null, null, null));
-        listItem = spy(new DataTypeListItem(view, dataTypeSelectComponent, dataTypeConstraintComponent, dataTypeListComponent, dataTypeManager, confirmation, nameFormatValidator, editModeToggleEvent));
-        listItem.init(dataTypeList);
-
         doReturn(structure).when(dataTypeManager).structure();
+
+        listItem = spy(new DataTypeListItem(view, dataTypeSelectComponent, dataTypeConstraintComponent, dataTypeListComponent, dataTypeManager, confirmation, nameFormatValidator, editModeToggleEvent, dataTypeChangedEvent));
+        listItem.setup();
+        listItem.init(dataTypeList);
     }
 
     @Test
     public void testSetup() {
-        listItem.setup();
-
         verify(view).init(listItem);
     }
 
     @Test
-    public void testGetElement() {
+    public void testGetContentElement() {
 
         final HTMLElement expectedElement = mock(HTMLElement.class);
 
         when(view.getElement()).thenReturn(expectedElement);
 
-        HTMLElement actualElement = listItem.getElement();
+        HTMLElement actualElement = listItem.getContentElement();
 
         assertEquals(expectedElement, actualElement);
     }
@@ -141,18 +149,41 @@ public class DataTypeListItemTest {
         final DataType expectedDataType = this.dataType;
         final int expectedLevel = 1;
 
+        doNothing().when(listItem).setupDragAndDropComponent();
+        doNothing().when(listItem).setupView();
+
         listItem.setupDataType(expectedDataType, expectedLevel);
 
         final InOrder inOrder = inOrder(listItem);
+
+        inOrder.verify(listItem).setupDragAndDropComponent();
         inOrder.verify(listItem).setupSelectComponent();
-        inOrder.verify(listItem).setupConstraintComponent();
         inOrder.verify(listItem).setupListComponent();
+        inOrder.verify(listItem).setupConstraintComponent();
         inOrder.verify(listItem).setupView();
 
         assertEquals(expectedDataType, listItem.getDataType());
         assertEquals(expectedLevel, listItem.getLevel());
     }
 
+    @Test
+    public void testSetupDragAndDropComponent() {
+
+        final DNDListComponent dragAndDropComponent = mock(DNDListComponent.class);
+        final HTMLElement htmlElement = mock(HTMLElement.class);
+        final HTMLElement expectedElement = mock(HTMLElement.class);
+
+        when(dataTypeList.getDNDListComponent()).thenReturn(dragAndDropComponent);
+        when(listItem.getContentElement()).thenReturn(htmlElement);
+        when(dragAndDropComponent.registerNewItem(htmlElement)).thenReturn(expectedElement);
+
+        listItem.setupDragAndDropComponent();
+
+        final HTMLElement actualElement = listItem.getDragAndDropElement();
+
+        assertEquals(expectedElement, actualElement);
+    }
+
     @Test
     public void testSetupConstraintComponent() {
 
@@ -211,6 +242,8 @@ public class DataTypeListItemTest {
 
         final DataType dataType = mock(DataType.class);
         when(listItem.getDataType()).thenReturn(dataType);
+        doNothing().when(listItem).setupIndentationLevel();
+        doNothing().when(listItem).hideTooltips();
 
         listItem.setupView();
 
@@ -218,6 +251,8 @@ public class DataTypeListItemTest {
         verify(view).setupConstraintComponent(dataTypeConstraintComponent);
         verify(view).setupListComponent(dataTypeListComponent);
         verify(view).setDataType(dataType);
+        verify(listItem).setupIndentationLevel();
+        verify(listItem).hideTooltips();
     }
 
     @Test
@@ -262,13 +297,28 @@ public class DataTypeListItemTest {
         final DataType dataType = mock(DataType.class);
         final List<DataType> dataTypes = singletonList(dataType);
 
-        listItem.refreshSubItems(dataTypes);
+        listItem.refreshSubItems(dataTypes, true);
 
         verify(dataTypeList).refreshSubItemsFromListItem(listItem, dataTypes);
+        verify(listItem, never()).expandOrCollapseSubTypes();
         verify(view).enableFocusMode();
         verify(view).toggleArrow(anyBoolean());
     }
 
+    @Test
+    public void testRefreshSubItemsNotSetFocus() {
+
+        final DataType dataType = mock(DataType.class);
+        final List<DataType> dataTypes = singletonList(dataType);
+
+        listItem.refreshSubItems(dataTypes, false);
+
+        verify(dataTypeList).refreshSubItemsFromListItem(listItem, dataTypes);
+        verify(listItem, never()).expandOrCollapseSubTypes();
+        verify(view, never()).enableFocusMode();
+        verify(view).toggleArrow(anyBoolean());
+    }
+
     @Test
     public void testEnableEditMode() {
 
@@ -299,10 +349,10 @@ public class DataTypeListItemTest {
         verify(view).enableFocusMode();
         verify(view).hideListYesLabel();
         verify(view).showListContainer();
-        verify(view).hideKebabMenu();
         verify(dataTypeSelectComponent).enableEditMode();
         verify(dataTypeConstraintComponent).enableEditMode();
         verify(editModeToggleEvent).fire(eventArgumentCaptor.capture());
+        verify(dataTypeList).fireOnDataTypeListItemUpdateCallback(listItem);
 
         assertTrue(eventArgumentCaptor.getValue().isEditModeEnabled());
     }
@@ -319,10 +369,10 @@ public class DataTypeListItemTest {
         verify(view, never()).enableFocusMode();
         verify(view, never()).hideListYesLabel();
         verify(view, never()).showListContainer();
-        verify(view, never()).hideKebabMenu();
         verify(dataTypeSelectComponent, never()).enableEditMode();
         verify(dataTypeConstraintComponent, never()).enableEditMode();
         verify(editModeToggleEvent, never()).fire(any());
+        verify(dataTypeList, never()).fireOnDataTypeListItemUpdateCallback(any(DataTypeListItem.class));
     }
 
     @Test
@@ -331,11 +381,13 @@ public class DataTypeListItemTest {
         when(view.isOnFocusMode()).thenReturn(true);
         doNothing().when(listItem).discardNewDataType();
         doNothing().when(listItem).closeEditMode();
+        doNothing().when(listItem).hideTooltips();
 
         listItem.disableEditMode();
 
         verify(listItem).discardNewDataType();
         verify(listItem).closeEditMode();
+        verify(listItem).hideTooltips();
     }
 
     @Test
@@ -347,6 +399,7 @@ public class DataTypeListItemTest {
 
         verify(listItem, never()).discardNewDataType();
         verify(listItem, never()).closeEditMode();
+        verify(listItem, never()).hideTooltips();
     }
 
     @Test
@@ -417,6 +470,7 @@ public class DataTypeListItemTest {
         doReturn(updatedDataTypes).when(listItem).persist(dataType);
         doReturn(dataType).when(listItem).getDataType();
         doReturn(newDataTypeHash).when(listItem).getNewDataTypeHash(dataType, referenceDataTypeHash);
+        doNothing().when(listItem).insertNewFieldIfDataTypeIsStructure(newDataTypeHash);
         when(dataTypeList.calculateParentHash(dataType)).thenReturn(referenceDataTypeHash);
 
         listItem.doSaveAndCloseEditMode(dataType).execute();
@@ -425,18 +479,20 @@ public class DataTypeListItemTest {
         verify(listItem).closeEditMode();
         verify(dataTypeList).fireOnDataTypeListItemUpdateCallback(newDataTypeHash);
         verify(listItem).insertNewFieldIfDataTypeIsStructure(newDataTypeHash);
+        verify(listItem).fireDataChangedEvent();
     }
 
     @Test
     public void testInsertNewFieldIfDataTypeIsStructureWhenDataTypeIsStructure() {
 
+        final DataTypeListItem newListItem = mock(DataTypeListItem.class);
         final DataType dataType = mock(DataType.class);
         final String hash = "hash";
 
-        when(dataTypeSelectComponent.getValue()).thenReturn(structure);
-        when(dataType.getSubDataTypes()).thenReturn(emptyList());
-        doReturn(dataType).when(listItem).getDataType();
-        doNothing().when(listItem).insertNestedField();
+        when(newListItem.getDataType()).thenReturn(dataType);
+        when(dataType.hasSubDataTypes()).thenReturn(false);
+        when(newListItem.isStructureType()).thenReturn(true);
+        when(dataTypeList.findItemByDataTypeHash(hash)).thenReturn(Optional.of(newListItem));
 
         listItem.insertNewFieldIfDataTypeIsStructure(hash);
 
@@ -446,12 +502,14 @@ public class DataTypeListItemTest {
     @Test
     public void testInsertNewFieldIfDataTypeIsStructureWhenDataTypeIsStructureButHasFields() {
 
+        final DataTypeListItem newListItem = mock(DataTypeListItem.class);
         final DataType dataType = mock(DataType.class);
         final String hash = "hash";
 
-        when(dataTypeSelectComponent.getValue()).thenReturn(structure);
-        when(dataType.getSubDataTypes()).thenReturn(asList(mock(DataType.class), mock(DataType.class)));
-        doReturn(dataType).when(listItem).getDataType();
+        when(newListItem.getDataType()).thenReturn(dataType);
+        when(dataType.hasSubDataTypes()).thenReturn(true);
+        when(newListItem.isStructureType()).thenReturn(true);
+        when(dataTypeList.findItemByDataTypeHash(hash)).thenReturn(Optional.of(newListItem));
 
         listItem.insertNewFieldIfDataTypeIsStructure(hash);
 
@@ -461,12 +519,14 @@ public class DataTypeListItemTest {
     @Test
     public void testInsertNewFieldIfDataTypeIsStructureWhenDataTypeIsNotStructure() {
 
+        final DataTypeListItem newListItem = mock(DataTypeListItem.class);
         final DataType dataType = mock(DataType.class);
         final String hash = "hash";
 
-        when(dataTypeSelectComponent.getValue()).thenReturn("String");
-        when(dataType.getSubDataTypes()).thenReturn(emptyList());
-        doReturn(dataType).when(listItem).getDataType();
+        when(newListItem.getDataType()).thenReturn(dataType);
+        when(dataType.hasSubDataTypes()).thenReturn(false);
+        when(newListItem.isStructureType()).thenReturn(false);
+        when(dataTypeList.findItemByDataTypeHash(hash)).thenReturn(Optional.of(newListItem));
 
         listItem.insertNewFieldIfDataTypeIsStructure(hash);
 
@@ -505,7 +565,8 @@ public class DataTypeListItemTest {
 
         doNothing().when(listItem).setupSelectComponent();
         doNothing().when(listItem).setupListComponent();
-        doNothing().when(listItem).refreshSubItems(subDataTypes);
+        doNothing().when(listItem).setupIndentationLevel();
+        doNothing().when(listItem).refreshSubItems(subDataTypes, true);
         doReturn(subDataTypes).when(dataType).getSubDataTypes();
         doReturn(dataType).when(listItem).discardDataTypeProperties();
 
@@ -515,7 +576,8 @@ public class DataTypeListItemTest {
         verify(listItem).setupListComponent();
         verify(listItem).setupSelectComponent();
         verify(listItem).setupConstraintComponent();
-        verify(listItem).refreshSubItems(subDataTypes);
+        verify(listItem).refreshSubItems(subDataTypes, true);
+        verify(listItem).setupIndentationLevel();
     }
 
     @Test
@@ -555,7 +617,6 @@ public class DataTypeListItemTest {
         verify(view).hideDataTypeNameInput();
         verify(view).disableFocusMode();
         verify(view).hideListContainer();
-        verify(view).showKebabMenu();
         verify(listItem).refreshListYesLabel();
         verify(dataTypeSelectComponent).disableEditMode();
         verify(dataTypeConstraintComponent).disableEditMode();
@@ -623,6 +684,7 @@ public class DataTypeListItemTest {
         doReturn(expectedConstraint).when(dataType).getConstraint();
         doReturn(expectedName).when(dataType).getName();
         doReturn(dataType).when(listItem).getDataType();
+        doNothing().when(listItem).hideTooltips();
 
         listItem.refresh();
 
@@ -632,6 +694,7 @@ public class DataTypeListItemTest {
         verify(view).setName(expectedName);
         verify(listItem).setupListComponent();
         verify(listItem).setupConstraintComponent();
+        verify(listItem).hideTooltips();
     }
 
     @Test
@@ -641,7 +704,7 @@ public class DataTypeListItemTest {
         final Command command = mock(Command.class);
 
         doReturn(dataType).when(listItem).getDataType();
-        doReturn(command).when(listItem).doRemove();
+        doReturn(command).when(listItem).removeItem();
 
         listItem.remove();
 
@@ -649,7 +712,20 @@ public class DataTypeListItemTest {
     }
 
     @Test
-    public void testDoRemove() {
+    public void testRemoveItem() {
+
+        final Command command = listItem.removeItem();
+
+        doNothing().when(listItem).destroyWithDependentTypes();
+
+        command.execute();
+
+        verify(dataTypeList).disableEditModeForChildren(listItem);
+        verify(listItem).destroyWithDependentTypes();
+    }
+
+    @Test
+    public void testDestroy() {
 
         final DataType dataType = mock(DataType.class);
         final DataType dataType0 = mock(DataType.class);
@@ -662,10 +738,46 @@ public class DataTypeListItemTest {
         doReturn(destroyedDataTypes).when(dataType).destroy();
         doReturn(removedDataTypes).when(listItem).removeTopLevelDataTypes(destroyedDataTypes);
         doReturn(dataType).when(listItem).getDataType();
+        doNothing().when(listItem).hideTooltips();
 
-        listItem.doRemove().execute();
+        listItem.destroy().execute();
 
         verify(dataTypeList).refreshItemsByUpdatedDataTypes(asList(dataType0, dataType3));
+        verify(listItem).fireDataChangedEvent();
+        verify(listItem).hideTooltips();
+    }
+
+    @Test
+    public void testDestroyWithDependentTypes() {
+
+        final DataType dataType = mock(DataType.class);
+        final DataType dataType0 = mock(DataType.class);
+        final DataType dataType1 = mock(DataType.class);
+        final List<DataType> removedDataTypes = asList(dataType0, dataType1);
+
+        when(dataType.destroy()).thenReturn(removedDataTypes);
+        doReturn(dataType).when(listItem).getDataType();
+        doNothing().when(listItem).destroy(any());
+
+        listItem.destroyWithDependentTypes();
+
+        verify(listItem).destroy(removedDataTypes);
+    }
+
+    @Test
+    public void testDestroyWithoutDependentTypes() {
+
+        final DataType dataType = mock(DataType.class);
+        final DataType dataType0 = mock(DataType.class);
+        final List<DataType> removedDataTypes = asList(dataType0);
+
+        when(dataType.destroyWithoutDependentTypes()).thenReturn(removedDataTypes);
+        doReturn(dataType).when(listItem).getDataType();
+        doNothing().when(listItem).destroy(any());
+
+        listItem.destroyWithoutDependentTypes();
+
+        verify(listItem).destroy(removedDataTypes);
     }
 
     @Test
@@ -739,14 +851,18 @@ public class DataTypeListItemTest {
     @Test
     public void testInsertFieldAboveWhenTheNewDataTypeIsTopLevel() {
 
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
         final DataType newDataType = mock(DataType.class);
         final DataType reference = mock(DataType.class);
+        final DataTypeListItem newListItem = mock(DataTypeListItem.class);
         final List<DataType> updatedDataTypes = asList(mock(DataType.class), mock(DataType.class));
         final String referenceDataTypeHash = "tDataType.id";
         final String newDataTypeHash = "tDataType.name";
 
         when(newDataType.isTopLevel()).thenReturn(true);
         when(newDataType.create(reference, ABOVE)).thenReturn(updatedDataTypes);
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+        when(dataTypeList.findItemByDataTypeHash(newDataTypeHash)).thenReturn(Optional.of(newListItem));
         when(dataTypeList.calculateParentHash(reference)).thenReturn(referenceDataTypeHash);
         doReturn(newDataTypeHash).when(listItem).getNewDataTypeHash(newDataType, referenceDataTypeHash);
         doReturn(dataTypeManager).when(dataTypeManager).fromNew();
@@ -756,21 +872,26 @@ public class DataTypeListItemTest {
         listItem.insertFieldAbove();
 
         verify(listItem).closeEditMode();
-        verify(listItem).enableEditModeAndUpdateCallbacks(newDataTypeHash);
         verify(dataTypeList).insertAbove(newDataType, reference);
+        verify(dndListComponent).refreshItemsCSSAndHTMLPosition();
+        verify(listItem).enableEditModeAndUpdateCallbacks(newDataTypeHash);
     }
 
     @Test
     public void testInsertFieldAboveWhenTheNewDataTypeIsNotTopLevel() {
 
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
         final DataType newDataType = mock(DataType.class);
         final DataType reference = mock(DataType.class);
+        final DataTypeListItem newListItem = mock(DataTypeListItem.class);
         final List<DataType> updatedDataTypes = asList(mock(DataType.class), mock(DataType.class));
         final String referenceDataTypeHash = "tDataType.id";
         final String newDataTypeHash = "tDataType.name";
 
         when(newDataType.isTopLevel()).thenReturn(false);
         when(newDataType.create(reference, ABOVE)).thenReturn(updatedDataTypes);
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+        when(dataTypeList.findItemByDataTypeHash(newDataTypeHash)).thenReturn(Optional.of(newListItem));
         when(dataTypeList.calculateParentHash(reference)).thenReturn(referenceDataTypeHash);
         doReturn(newDataTypeHash).when(listItem).getNewDataTypeHash(newDataType, referenceDataTypeHash);
         doReturn(dataTypeManager).when(dataTypeManager).fromNew();
@@ -780,13 +901,15 @@ public class DataTypeListItemTest {
         listItem.insertFieldAbove();
 
         verify(listItem).closeEditMode();
-        verify(listItem).enableEditModeAndUpdateCallbacks(newDataTypeHash);
         verify(dataTypeList).refreshItemsByUpdatedDataTypes(updatedDataTypes);
+        verify(dndListComponent).refreshItemsCSSAndHTMLPosition();
+        verify(listItem).enableEditModeAndUpdateCallbacks(newDataTypeHash);
     }
 
     @Test
     public void testInsertFieldBelowWhenTheNewDataTypeIsTopLevel() {
 
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
         final DataType newDataType = mock(DataType.class);
         final DataType reference = mock(DataType.class);
         final List<DataType> updatedDataTypes = asList(mock(DataType.class), mock(DataType.class));
@@ -796,6 +919,7 @@ public class DataTypeListItemTest {
         when(newDataType.isTopLevel()).thenReturn(true);
         when(newDataType.create(reference, BELOW)).thenReturn(updatedDataTypes);
         when(dataTypeList.calculateParentHash(reference)).thenReturn(referenceDataTypeHash);
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
         doReturn(newDataTypeHash).when(listItem).getNewDataTypeHash(newDataType, referenceDataTypeHash);
         doReturn(dataTypeManager).when(dataTypeManager).fromNew();
         doReturn(newDataType).when(dataTypeManager).get();
@@ -811,6 +935,7 @@ public class DataTypeListItemTest {
     @Test
     public void testInsertFieldBelowWhenTheNewDataTypeIsNotTopLevel() {
 
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
         final DataType newDataType = mock(DataType.class);
         final DataType reference = mock(DataType.class);
         final List<DataType> updatedDataTypes = asList(mock(DataType.class), mock(DataType.class));
@@ -820,6 +945,7 @@ public class DataTypeListItemTest {
         when(newDataType.isTopLevel()).thenReturn(false);
         when(newDataType.create(reference, BELOW)).thenReturn(updatedDataTypes);
         when(dataTypeList.calculateParentHash(reference)).thenReturn(referenceDataTypeHash);
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
         doReturn(newDataTypeHash).when(listItem).getNewDataTypeHash(newDataType, referenceDataTypeHash);
         doReturn(dataTypeManager).when(dataTypeManager).fromNew();
         doReturn(newDataType).when(dataTypeManager).get();
@@ -904,6 +1030,26 @@ public class DataTypeListItemTest {
         verify(dataTypeConstraintComponent).disable();
     }
 
+    @Test
+    public void testRefreshConstraintComponentWhenSelectedTypeIsContext() {
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(CONTEXT.getName());
+
+        listItem.refreshConstraintComponent();
+
+        verify(dataTypeConstraintComponent).disable();
+    }
+
+    @Test
+    public void testRefreshConstraintComponentWhenSelectedTypeIsAList() {
+
+        when(dataTypeListComponent.getValue()).thenReturn(true);
+
+        listItem.refreshConstraintComponent();
+
+        verify(dataTypeConstraintComponent).disable();
+    }
+
     @Test
     public void testRefreshConstraintComponentWhenSelectedTypeIsNotBooleanNeitherStructure() {
 
@@ -914,6 +1060,156 @@ public class DataTypeListItemTest {
         verify(dataTypeConstraintComponent).enable();
     }
 
+    @Test
+    public void testRefreshConstraintComponentWhenTypeIsIndirectTypeOfCanNotHaveConstraints() {
+
+        doReturn(true).when(listItem).isIndirectCanNotHaveConstraintType();
+
+        listItem.refreshConstraintComponent();
+
+        verify(dataTypeConstraintComponent).disable();
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsBoolean() {
+
+        final String currentValue = "tIndirectBoolean";
+        final DataType dataType1 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1);
+
+        when(dataType1.getName()).thenReturn(currentValue);
+        when(dataType1.getType()).thenReturn(BOOLEAN.getName());
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(currentValue);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertTrue(actual);
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsBooleanRecursive() {
+
+        // some(tIndirectType) -> tIndirectType(tIndirectBoolean) -> tIndirectBoolean(boolean)
+        final String indirectType = "tIndirectType";
+        final String tBoolean = "tIndirectBoolean";
+        final DataType dataType1 = mock(DataType.class);
+        final DataType dataType2 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1, dataType2);
+
+        when(dataType1.getName()).thenReturn(indirectType);
+        when(dataType1.getType()).thenReturn(tBoolean);
+        when(dataType2.getName()).thenReturn(tBoolean);
+        when(dataType2.getType()).thenReturn(BOOLEAN.getName());
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(indirectType);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertTrue(actual);
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsStructureRecursive() {
+
+        // some(tIndirectType) -> tIndirectType(tIndirectStructure) -> tIndirectStructure(Structure)
+        final String indirectType = "tIndirectType";
+        final String tIndirectStructure = "tIndirectStructure";
+        final DataType dataType1 = mock(DataType.class);
+        final DataType dataType2 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1, dataType2);
+
+        when(dataType1.getName()).thenReturn(indirectType);
+        when(dataType1.getType()).thenReturn(tIndirectStructure);
+        when(dataType2.getName()).thenReturn(tIndirectStructure);
+        when(dataType2.getType()).thenReturn(structure);
+        when(dataTypeSelectComponent.getValue()).thenReturn(indirectType);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertTrue(actual);
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsStructure() {
+
+        final String currentValue = "tIndirectStructure";
+        final DataType dataType1 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1);
+
+        when(dataType1.getName()).thenReturn(currentValue);
+        when(dataType1.getType()).thenReturn(structure);
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(currentValue);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertTrue(actual);
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsContextRecursive() {
+
+        // some(tIndirectType) -> tIndirectType(tIndirectContext) -> tIndirectContext(Context)
+        final String indirectType = "tIndirectType";
+        final String tIndirectContext = "tIndirectContext";
+        final DataType dataType1 = mock(DataType.class);
+        final DataType dataType2 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1, dataType2);
+
+        when(dataType1.getName()).thenReturn(indirectType);
+        when(dataType1.getType()).thenReturn(tIndirectContext);
+        when(dataType2.getName()).thenReturn(tIndirectContext);
+        when(dataType2.getType()).thenReturn(CONTEXT.getName());
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(indirectType);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertTrue(actual);
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsContext() {
+
+        final String currentValue = "tIndirectContext";
+        final DataType dataType1 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1);
+
+        when(dataType1.getName()).thenReturn(currentValue);
+        when(dataType1.getType()).thenReturn(CONTEXT.getName());
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(currentValue);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertTrue(actual);
+    }
+
+    @Test
+    public void testIsIndirectTypeOfWhenIsOtherType() {
+
+        final String currentValue = "tIndirectOtherType";
+        final DataType dataType1 = mock(DataType.class);
+        final List<DataType> customDataTypes = asList(dataType1);
+
+        when(dataType1.getName()).thenReturn(currentValue);
+        when(dataType1.getType()).thenReturn(STRING.getName());
+
+        when(dataTypeSelectComponent.getValue()).thenReturn(currentValue);
+        when(dataTypeSelectComponent.getCustomDataTypes()).thenReturn(customDataTypes);
+
+        final boolean actual = listItem.isIndirectCanNotHaveConstraintType();
+
+        assertFalse(actual);
+    }
+
     @Test
     public void testEnableEditModeAndUpdateCallbacks() {
 
@@ -943,6 +1239,107 @@ public class DataTypeListItemTest {
         assertFalse(listItem.isReadOnly());
     }
 
+    @Test
+    public void testRefreshItemsCSSAndHTMLPosition() {
+        listItem.refreshItemsCSSAndHTMLPosition();
+        verify(dataTypeList).refreshItemsCSSAndHTMLPosition();
+    }
+
+    @Test
+    public void testSetPositionX() {
+
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
+        final Element element = mock(Element.class);
+        final int positionX = 2;
+
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+
+        listItem.setPositionX(element, positionX);
+
+        verify(dndListComponent).setPositionX(element, positionX);
+    }
+
+    @Test
+    public void testSetPositionY() {
+
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
+        final Element element = mock(Element.class);
+        final int positionY = 2;
+
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+
+        listItem.setPositionY(element, positionY);
+
+        verify(dndListComponent).setPositionY(element, positionY);
+    }
+
+    @Test
+    public void testGetPositionY() {
+
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
+        final Element element = mock(Element.class);
+        final Integer expectedPositionY = 2;
+
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+        when(dndListComponent.getPositionY(element)).thenReturn(expectedPositionY);
+
+        final Integer actualPositionY = listItem.getPositionY(element);
+
+        assertEquals(expectedPositionY, actualPositionY);
+    }
+
+    @Test
+    public void testGetDragAndDropListElement() {
+
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
+        final HTMLElement expectedHTMLElement = mock(HTMLElement.class);
+
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+        when(dndListComponent.getElement()).thenReturn(expectedHTMLElement);
+
+        final HTMLElement actualHTMLElement = listItem.getDragAndDropListElement();
+
+        assertEquals(expectedHTMLElement, actualHTMLElement);
+    }
+
+    @Test
+    public void testSetupIndentationLevel() {
+
+        final HTMLElement dragAndDropElement = mock(HTMLElement.class);
+        final DNDListComponent dndListComponent = mock(DNDListComponent.class);
+
+        when(dataTypeList.getDNDListComponent()).thenReturn(dndListComponent);
+        doReturn(dragAndDropElement).when(listItem).getDragAndDropElement();
+        doReturn(5).when(listItem).getLevel();
+
+        listItem.setupIndentationLevel();
+
+        verify(dndListComponent).setPositionX(dragAndDropElement, 4);
+    }
+
+    @Test
+    public void testHideTooltips() {
+
+        final HTMLElement listItems = mock(HTMLElement.class);
+        final NodeList<Element> tooltips = spy(new NodeList<>());
+        final Element element0 = mock(Element.class);
+        final Element element1 = mock(Element.class);
+
+        doReturn(element0).when(tooltips).getAt(0);
+        doReturn(element1).when(tooltips).getAt(1);
+        tooltips.length = 2;
+        element0.parentNode = listItems;
+        element1.parentNode = listItems;
+
+        doReturn(listItems).when(dataTypeList).getListItems();
+        doReturn(tooltips).when(listItems).querySelectorAll(".tooltip");
+
+        listItem.hideTooltips();
+
+        verify(listItems).removeChild(element0);
+        verify(listItems).removeChild(element1);
+    }
+
     private DataType makeDataType() {
         return new DataType(null);
     }
