@@ -16,7 +16,6 @@
 
 package org.kie.workbench.common.forms.editor.client.editor.changes;
 
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
@@ -34,6 +33,7 @@ import org.kie.workbench.common.forms.editor.client.editor.changes.displayers.Mo
 import org.kie.workbench.common.forms.editor.client.editor.changes.displayers.conflicts.ConflictsDisplayer;
 import org.kie.workbench.common.forms.editor.client.editor.changes.displayers.newProperties.NewPropertiesDisplayer;
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
+import org.kie.workbench.common.forms.editor.model.FormModelerContentError;
 import org.kie.workbench.common.forms.editor.model.impl.FormModelSynchronizationResultImpl;
 import org.kie.workbench.common.forms.editor.model.impl.TypeConflictImpl;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorRenderingContext;
@@ -52,7 +52,13 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mvp.Command;
 
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.anyList;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ChangesNotificationDisplayerTest {
@@ -143,10 +149,16 @@ public class ChangesNotificationDisplayerTest {
         verify(view).init(presenter);
     }
 
+    @Test
+    public void testShowWithModelError() {
+        content.setError(mock(FormModelerContentError.class));
+
+        presenter.show(content, command);
+    }
+
     @Test
     public void testShowEmptySynchronization() {
-        presenter.show(content,
-                       command);
+        presenter.show(content, command);
 
         verify(view, never()).show();
     }
