@@ -37,15 +37,6 @@ public abstract class AbstractCanvasGraphCommand
         extends AbstractCanvasCommand
         implements HasGraphCommand<AbstractCanvasHandler> {
 
-    private boolean canvasCommandFirst = false;
-
-    public AbstractCanvasGraphCommand() {
-    }
-
-    public AbstractCanvasGraphCommand(boolean canvasCommandFirst) {
-        this.canvasCommandFirst = canvasCommandFirst;
-    }
-
     /**
      * The private instance of the graph command.
      * It's a private stateful command instance - will be used for undoing the operation on the graph.
@@ -85,40 +76,32 @@ public abstract class AbstractCanvasGraphCommand
 
     @Override
     public CommandResult<CanvasViolation> allow(final AbstractCanvasHandler context) {
-        final CommandResult<CanvasViolation> result = canvasCommandFirst ?
-                performOperationOnCanvas(context, CommandOperation.ALLOW) :
-                performOperationOnGraph(context, CommandOperation.ALLOW);
-
+        final CommandResult<CanvasViolation> result = performOperationOnGraph(context, CommandOperation.ALLOW);
         if (canDoNexOperation(result)) {
-            return canvasCommandFirst ? performOperationOnGraph(context, CommandOperation.ALLOW) :
-                    performOperationOnCanvas(context, CommandOperation.ALLOW);
+            return performOperationOnCanvas(context, CommandOperation.ALLOW);
         }
         return result;
     }
 
     @Override
     public CommandResult<CanvasViolation> execute(final AbstractCanvasHandler context) {
-        final CommandResult<CanvasViolation> result = canvasCommandFirst ?
-                performOperationOnCanvas(context, CommandOperation.EXECUTE) :
-                performOperationOnGraph(context, CommandOperation.EXECUTE);
-
+        CommandResult<CanvasViolation> result = performOperationOnGraph(context, CommandOperation.EXECUTE);
         if (canDoNexOperation(result)) {
-            return canvasCommandFirst ? performOperationOnGraph(context, CommandOperation.EXECUTE) :
+            final CommandResult<CanvasViolation> canvasResult =
                     performOperationOnCanvas(context, CommandOperation.EXECUTE);
+            if (!canDoNexOperation(canvasResult)) {
+                performOperationOnGraph(context, CommandOperation.UNDO);
+                return canvasResult;
+            }
         }
         return result;
     }
 
     @Override
     public CommandResult<CanvasViolation> undo(final AbstractCanvasHandler context) {
-        final CommandResult<CanvasViolation> result = canvasCommandFirst ?
-                performOperationOnCanvas(context, CommandOperation.UNDO) :
-                performOperationOnGraph(context, CommandOperation.UNDO);
-
+        final CommandResult<CanvasViolation> result = performOperationOnGraph(context, CommandOperation.UNDO);
         if (canDoNexOperation(result)) {
-            return canvasCommandFirst ?
-                    performOperationOnGraph(context, CommandOperation.UNDO) :
-                    performOperationOnCanvas(context, CommandOperation.UNDO);
+            return performOperationOnCanvas(context, CommandOperation.UNDO);
         }
         return result;
     }
@@ -141,6 +124,8 @@ public abstract class AbstractCanvasGraphCommand
         getCanvasCommand(context);
         // Obtain the graph execution context and execute the graph command updates.
         final GraphCommandExecutionContext graphContext = context.getGraphExecutionContext();
+        context.setStaticContext(graphContext);
+
         if (Objects.isNull(graphContext)) {
             //skipping command in case there is no graph execution context
             return CanvasCommandResultBuilder.SUCCESS;
@@ -182,24 +167,4 @@ public abstract class AbstractCanvasGraphCommand
     private boolean canDoNexOperation(CommandResult<CanvasViolation> result) {
         return null == result || !CommandUtils.isError(result);
     }
-
-    @Override
-    public String toString() {
-        return "[" +
-                this.getClass().getName() +
-                "]" +
-                " [canvasCommand=" +
-                (null != canvasCommand ? canvasCommand.toString() : "null") +
-                " [graphCommand=" +
-                (null != graphCommand ? graphCommand.toString() : null) +
-                "]";
-    }
-
-    protected boolean isCanvasCommandFirst() {
-        return canvasCommandFirst;
-    }
-
-    protected void setCanvasCommandFirst(boolean canvasCommandFirst) {
-        this.canvasCommandFirst = canvasCommandFirst;
-    }
 }
