@@ -19,14 +19,12 @@ package org.kie.workbench.common.stunner.core.client.canvas.command;
 import java.util.Collection;
 import java.util.function.Consumer;
 
-import javax.enterprise.context.ApplicationScoped;
-import javax.inject.Inject;
-
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommand;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.definition.morph.MorphDefinition;
+import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
@@ -39,20 +37,13 @@ import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 import org.kie.workbench.common.stunner.core.graph.processing.traverse.content.ChildrenTraverseProcessor;
 import org.kie.workbench.common.stunner.core.graph.processing.traverse.content.ViewTraverseProcessor;
 
-@ApplicationScoped
-public class DefaultCanvasCommandFactory implements CanvasCommandFactory<AbstractCanvasHandler> {
+public abstract class DefaultCanvasCommandFactory implements CanvasCommandFactory<AbstractCanvasHandler> {
 
     private final ManagedInstance<ChildrenTraverseProcessor> childrenTraverseProcessors;
     private final ManagedInstance<ViewTraverseProcessor> viewTraverseProcessors;
 
-    protected DefaultCanvasCommandFactory() {
-        this(null,
-             null);
-    }
-
-    @Inject
-    public DefaultCanvasCommandFactory(final ManagedInstance<ChildrenTraverseProcessor> childrenTraverseProcessors,
-                                       final ManagedInstance<ViewTraverseProcessor> viewTraverseProcessors) {
+    protected DefaultCanvasCommandFactory(final ManagedInstance<ChildrenTraverseProcessor> childrenTraverseProcessors,
+                                          final ManagedInstance<ViewTraverseProcessor> viewTraverseProcessors) {
         this.childrenTraverseProcessors = childrenTraverseProcessors;
         this.viewTraverseProcessors = viewTraverseProcessors;
     }
@@ -109,24 +100,33 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
     }
 
     @Override
+    @SuppressWarnings("unchecked")
     public CanvasCommand<AbstractCanvasHandler> setChildNode(final Node parent,
                                                              final Node candidate) {
-        return new SetChildNodeCommand(parent,
-                                       candidate);
+        return new SetChildrenCommand(parent,
+                                      candidate);
     }
 
     @Override
+    @SuppressWarnings("unchecked")
     public CanvasCommand<AbstractCanvasHandler> removeChild(final Node parent,
                                                             final Node candidate) {
-        return new RemoveChildCommand(parent,
-                                      candidate);
+        return new RemoveChildrenCommand(parent,
+                                         candidate);
     }
 
     @Override
     public CanvasCommand<AbstractCanvasHandler> updateChildNode(final Node parent,
                                                                 final Node candidate) {
-        return new UpdateChildNodeCommand(parent,
-                                          candidate);
+        return new UpdateChildrenCommand(parent,
+                                         candidate);
+    }
+
+    @Override
+    public CanvasCommand<AbstractCanvasHandler> updateChildren(final Node parent,
+                                                               final Collection<Node> candidates) {
+        return new UpdateChildrenCommand(parent,
+                                         candidates);
     }
 
     @Override
@@ -150,6 +150,13 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
                                          candidate);
     }
 
+    @Override
+    public CanvasCommand<AbstractCanvasHandler> updateDockNode(final Node parent,
+                                                               final Node candidate,
+                                                               final boolean adjustPosition) {
+        return new UpdateDockNodeCommand(parent, candidate, adjustPosition);
+    }
+
     @Override
     public CanvasCommand<AbstractCanvasHandler> draw() {
         return new DrawCanvasCommand(newChildrenTraverseProcessor(),
@@ -201,6 +208,15 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
                                                 value);
     }
 
+    @Override
+    public CanvasCommand<AbstractCanvasHandler> updateDomainObjectPropertyValue(final DomainObject domainObject,
+                                                                                final String propertyId,
+                                                                                final Object value) {
+        return new UpdateDomainObjectPropertyCommand(domainObject,
+                                                     propertyId,
+                                                     value);
+    }
+
     @Override
     public CanvasCommand<AbstractCanvasHandler> clearCanvas() {
         return new ClearCommand();
@@ -217,18 +233,18 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
     }
 
     @Override
-    public CanvasCommand<AbstractCanvasHandler> addControlPoint(Edge candidate, ControlPoint... controlPoints) {
-        return new AddControlPointCommand(candidate, controlPoints);
+    public CanvasCommand<AbstractCanvasHandler> addControlPoint(Edge candidate, ControlPoint controlPoint, int index) {
+        return new AddControlPointCommand(candidate, controlPoint, index);
     }
 
     @Override
-    public CanvasCommand<AbstractCanvasHandler> deleteControlPoint(Edge candidate, ControlPoint... controlPoints) {
-        return new DeleteControlPointCommand(candidate, controlPoints);
+    public CanvasCommand<AbstractCanvasHandler> deleteControlPoint(Edge candidate, int index) {
+        return new DeleteControlPointCommand(candidate, index);
     }
 
     @Override
-    public CanvasCommand<AbstractCanvasHandler> updateControlPointPosition(Edge candidate, ControlPoint controlPoint, Point2D position) {
-        return new UpdateControlPointPositionCommand(candidate, controlPoint, position);
+    public CanvasCommand<AbstractCanvasHandler> updateControlPointPosition(Edge candidate, ControlPoint[] controlPoints) {
+        return new UpdateControlPointPositionCommand(candidate, controlPoints);
     }
 
     protected ChildrenTraverseProcessor newChildrenTraverseProcessor() {
