@@ -18,11 +18,11 @@ package org.kie.workbench.common.stunner.core.client.canvas.controls.builder.imp
 
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.enterprise.context.Dependent;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
-import org.kie.workbench.common.stunner.core.client.api.ClientDefinitionManager;
-import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.AbstractCanvasHandlerControl;
@@ -34,35 +34,27 @@ import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.RequiresCommandManager;
 import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
-import org.kie.workbench.common.stunner.core.command.impl.CompositeCommandImpl;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.MagnetConnection;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
+import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 
 @Dependent
-public class EdgeBuilderControlImpl extends AbstractCanvasHandlerControl<AbstractCanvasHandler> implements EdgeBuilderControl<AbstractCanvasHandler> {
+@Default
+public class EdgeBuilderControlImpl
+        extends AbstractCanvasHandlerControl<AbstractCanvasHandler>
+        implements EdgeBuilderControl<AbstractCanvasHandler> {
 
     private static Logger LOGGER = Logger.getLogger(EdgeBuilderControlImpl.class.getName());
 
-    private final ClientDefinitionManager clientDefinitionManager;
-    private final ShapeManager shapeManager;
     private final CanvasCommandFactory<AbstractCanvasHandler> commandFactory;
     private RequiresCommandManager.CommandManagerProvider<AbstractCanvasHandler> commandManagerProvider;
 
-    protected EdgeBuilderControlImpl() {
-        this(null,
-             null,
-             null);
-    }
-
     @Inject
-    public EdgeBuilderControlImpl(final ClientDefinitionManager clientDefinitionManager,
-                                  final ShapeManager shapeManager,
-                                  final CanvasCommandFactory<AbstractCanvasHandler> commandFactory) {
-        this.clientDefinitionManager = clientDefinitionManager;
-        this.shapeManager = shapeManager;
+    public EdgeBuilderControlImpl(final CanvasCommandFactory<AbstractCanvasHandler> commandFactory) {
         this.commandFactory = commandFactory;
     }
 
@@ -75,16 +67,16 @@ public class EdgeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
     public boolean allows(final EdgeBuildRequest request) {
         final double x = request.getX();
         final double y = request.getY();
-        final Edge<View<?>, Node> edge = request.getEdge();
+        final Edge<? extends ViewConnector<?>, Node> edge = (Edge<? extends ViewConnector<?>, Node>) request.getEdge();
         final AbstractCanvasHandler<?, ?> wch = canvasHandler;
-        final Node<View<?>, Edge> inNode = request.getInNode();
-        final Node<View<?>, Edge> outNode = request.getOutNode();
+        final Node<? extends View<?>, Edge> inNode = request.getInNode();
+        final Node<? extends View<?>, Edge> outNode = request.getOutNode();
         boolean allowsSourceConn = true;
         if (null != inNode) {
             final CommandResult<CanvasViolation> cr1 = getCommandManager().allow(wch,
                                                                                  commandFactory.setSourceNode(inNode,
                                                                                                               edge,
-                                                                                                              MagnetConnection.Builder.forElement(inNode)));
+                                                                                                              MagnetConnection.Builder.forTarget(inNode, outNode)));
             allowsSourceConn = isAllowed(cr1);
         }
         boolean allowsTargetConn = true;
@@ -92,7 +84,7 @@ public class EdgeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
             final CommandResult<CanvasViolation> cr2 = getCommandManager().allow(wch,
                                                                                  commandFactory.setTargetNode(outNode,
                                                                                                               edge,
-                                                                                                              MagnetConnection.Builder.forElement(outNode)));
+                                                                                                              MagnetConnection.Builder.forTarget(outNode, inNode)));
             allowsTargetConn = isAllowed(cr2);
         }
         return allowsSourceConn & allowsTargetConn;
@@ -104,24 +96,24 @@ public class EdgeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
                       final BuildCallback buildCallback) {
         final double x = request.getX();
         final double y = request.getY();
-        final Edge<View<?>, Node> edge = request.getEdge();
+        final Edge<? extends ViewConnector<?>, Node> edge = request.getEdge();
         final AbstractCanvasHandler<?, ?> wch = canvasHandler;
-        final Node<View<?>, Edge> inNode = request.getInNode();
-        final Node<View<?>, Edge> outNode = request.getOutNode();
+        final Node<? extends View<?>, Edge> inNode = request.getInNode();
+        final Node<? extends View<?>, Edge> outNode = request.getOutNode();
         final Canvas canvas = canvasHandler.getCanvas();
         if (null == inNode) {
             throw new RuntimeException(" An edge must be into the outgoing edges list from a node.");
         }
         final String ssid = canvasHandler.getDiagram().getMetadata().getShapeSetId();
-        final CompositeCommandImpl.CompositeCommandBuilder commandBuilder = new CompositeCommandImpl.CompositeCommandBuilder()
+        final CompositeCommand.Builder commandBuilder = new CompositeCommand.Builder()
                 .addCommand(commandFactory.addConnector(inNode,
                                                         edge,
-                                                        MagnetConnection.Builder.forElement(inNode),
+                                                        MagnetConnection.Builder.forTarget(inNode, outNode),
                                                         ssid));
         if (null != outNode) {
             commandBuilder.addCommand(commandFactory.setTargetNode(outNode,
                                                                    edge,
-                                                                   MagnetConnection.Builder.forElement(outNode)));
+                                                                   MagnetConnection.Builder.forTarget(outNode, inNode)));
         }
         final CommandResult<CanvasViolation> results = getCommandManager().execute(wch,
                                                                                    commandBuilder.build());
@@ -135,7 +127,11 @@ public class EdgeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
     }
 
     @Override
-    protected void doDisable() {
+    protected void doInit() {
+    }
+
+    @Override
+    protected void doDestroy() {
         commandManagerProvider = null;
     }
 
