@@ -20,18 +20,21 @@ import java.util.logging.Logger;
 
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementsClearEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent.Key;
-import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.session.Session;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.command.Command;
 
 import static org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher.doKeysMatch;
@@ -40,9 +43,10 @@ import static org.kie.workbench.common.stunner.core.client.canvas.controls.keybo
  * This session command copy to the clipboard using {@link CopySelectionSessionCommand} selected elements and delete them using the {@link DeleteSelectionSessionCommand}. *
  */
 @Dependent
-public class CutSelectionSessionCommand extends AbstractSelectionAwareSessionCommand<ClientFullSession> {
+@Default
+public class CutSelectionSessionCommand extends AbstractSelectionAwareSessionCommand<EditorSession> {
 
-    private final CopySelectionSessionCommand copySelectionSessionCommand;
+    private CopySelectionSessionCommand copySelectionSessionCommand;
     private final DeleteSelectionSessionCommand deleteSelectionSessionCommand;
     private final Event<CutSelectionSessionCommandExecutedEvent> commandExecutedEvent;
     private static Logger LOGGER = Logger.getLogger(CopySelectionSessionCommand.class.getName());
@@ -56,34 +60,44 @@ public class CutSelectionSessionCommand extends AbstractSelectionAwareSessionCom
     }
 
     @Inject
-    public CutSelectionSessionCommand(final SessionCommandFactory sessionCommandFactory,
-                                      final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                      final Event<CutSelectionSessionCommandExecutedEvent> commandExecutedEvent) {
+    public CutSelectionSessionCommand(final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                      final Event<CutSelectionSessionCommandExecutedEvent> commandExecutedEvent,
+                                      final SessionManager sessionManager) {
         super(true);
-        this.copySelectionSessionCommand = sessionCommandFactory.newCopySelectionCommand();
-        this.deleteSelectionSessionCommand = sessionCommandFactory.newDeleteSelectedElementsCommand();
+        this.copySelectionSessionCommand = CopySelectionSessionCommand.getInstance(sessionManager);
+        this.deleteSelectionSessionCommand = DeleteSelectionSessionCommand.getInstance(sessionManager);
         this.sessionCommandManager = sessionCommandManager;
         this.commandExecutedEvent = commandExecutedEvent;
     }
 
     @Override
-    public void bind(final ClientFullSession session) {
-        super.bind(session);
-        copySelectionSessionCommand.bind(session);
-        deleteSelectionSessionCommand.bind(session);
+    public void bind(final EditorSession session) {
         session.getKeyboardControl().addKeyShortcutCallback(this::onKeyDownEvent);
+
+        super.bind(session);
         this.clipboardControl = session.getClipboardControl();
     }
 
-    protected void onKeyDownEvent(final Key... keys) {
-        handleCtrlX(keys);
+    public void setCopySelectionSessionCommand(CopySelectionSessionCommand copySelectionSessionCommand) {
+        this.copySelectionSessionCommand = copySelectionSessionCommand;
     }
 
-    private void handleCtrlX(Key[] keys) {
+    @Override
+    public boolean accepts(final ClientSession session) {
+        return session instanceof EditorSession;
+    }
+
+    protected void onKeyDownEvent(final Key... keys) {
+        if (isEnabled()) {
+            handleCtrlX(keys);
+        }
+    }
+
+    private void handleCtrlX(final Key[] keys) {
         if (doKeysMatch(keys,
                         Key.CONTROL,
                         Key.X)) {
-            this.execute(newDefaultCallback("Error while trying to cut selected items."));
+            this.execute();
         }
     }
 
@@ -108,6 +122,12 @@ public class CutSelectionSessionCommand extends AbstractSelectionAwareSessionCom
         });
     }
 
+    @Override
+    protected void doDestroy() {
+        super.doDestroy();
+        clipboardControl = null;
+    }
+
     @Override
     protected void handleCanvasSelectionEvent(final CanvasSelectionEvent event) {
         if (event.getIdentifiers().isEmpty() || onlyCanvasRootSelected(event)) {
