@@ -17,20 +17,21 @@
 package org.kie.workbench.common.stunner.core.client.session.command.impl;
 
 import java.util.Collection;
-import java.util.logging.Level;
+import java.util.Objects;
 import java.util.logging.Logger;
 import java.util.stream.Collectors;
 
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
-import javax.enterprise.event.Observes;
+import javax.enterprise.inject.Any;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
+import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
-import org.kie.workbench.common.stunner.core.client.canvas.event.AbstractCanvasHandlerEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
+import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementsClearEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
@@ -38,48 +39,79 @@ import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
-import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.session.Session;
-import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Element;
+import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher.doKeysMatch;
 
 /**
  * This session command obtains the selected elements on session and executes a delete operation for each one.
  * It also captures the <code>DELETE</code> keyboard event and fires the delete operation as well.
  */
 @Dependent
-public class DeleteSelectionSessionCommand extends AbstractClientSessionCommand<ClientFullSession> {
+@Default
+public class DeleteSelectionSessionCommand extends AbstractSelectionAwareSessionCommand<EditorSession> {
 
     private static Logger LOGGER = Logger.getLogger(DeleteSelectionSessionCommand.class.getName());
 
     private final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
-    private final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
+    private final ManagedInstance<CanvasCommandFactory<AbstractCanvasHandler>> canvasCommandFactoryInstance;
     private final Event<CanvasClearSelectionEvent> clearSelectionEvent;
+    private final DefinitionUtils definitionUtils;
+    private CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
 
     protected DeleteSelectionSessionCommand() {
         this(null,
              null,
-             null);
+             null,
+             null,
+             null
+        );
     }
 
     @Inject
     public DeleteSelectionSessionCommand(final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                         final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
-                                         final Event<CanvasClearSelectionEvent> clearSelectionEvent) {
+                                         final @Any ManagedInstance<CanvasCommandFactory<AbstractCanvasHandler>> canvasCommandFactoryInstance,
+                                         final Event<CanvasClearSelectionEvent> clearSelectionEvent,
+                                         final DefinitionUtils definitionUtils,
+                                         final SessionManager sessionmanager) {
         super(false);
         this.sessionCommandManager = sessionCommandManager;
-        this.canvasCommandFactory = canvasCommandFactory;
+        this.canvasCommandFactoryInstance = canvasCommandFactoryInstance;
         this.clearSelectionEvent = clearSelectionEvent;
+        this.definitionUtils = definitionUtils;
+        SessionSingletonCommandsFactory.createOrPut(this, sessionmanager);
+    }
+
+    public static DeleteSelectionSessionCommand getInstance(SessionManager sessionManager) {
+        return SessionSingletonCommandsFactory.getInstanceDelete(null, null, null, null, sessionManager);
+    }
+
+    public static DeleteSelectionSessionCommand getInstance(final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                                            final ManagedInstance<CanvasCommandFactory<AbstractCanvasHandler>> canvasCommandFactoryInstance,
+                                                            final Event<CanvasClearSelectionEvent> clearSelectionEvent,
+                                                            final DefinitionUtils definitionUtils,
+                                                            final SessionManager sessionmanager) {
+
+        return SessionSingletonCommandsFactory.getInstanceDelete(sessionCommandManager, canvasCommandFactoryInstance, clearSelectionEvent, definitionUtils, sessionmanager);
     }
 
     @Override
-    public void bind(final ClientFullSession session) {
+    public void bind(final EditorSession session) {
         super.bind(session);
         session.getKeyboardControl().addKeyShortcutCallback(this::onKeyDownEvent);
+        this.canvasCommandFactory = this.loadCanvasFactory(canvasCommandFactoryInstance, definitionUtils);
+    }
+
+    @Override
+    public boolean accepts(final ClientSession session) {
+        return session instanceof EditorSession;
     }
 
     @Override
@@ -87,18 +119,23 @@ public class DeleteSelectionSessionCommand extends AbstractClientSessionCommand<
     public <V> void execute(final Callback<V> callback) {
         checkNotNull("callback",
                      callback);
-        if (null != getSession().getSelectionControl()) {
-            final AbstractCanvasHandler canvasHandler = (AbstractCanvasHandler) getSession().getCanvasHandler();
+        if (null != getSession() && null != getSession().getSelectionControl()) {
+            final AbstractCanvasHandler canvasHandler = getSession().getCanvasHandler();
             final SelectionControl<AbstractCanvasHandler, Element> selectionControl = getSession().getSelectionControl();
             final Collection<String> selectedItems = selectionControl.getSelectedItems();
+
+            clearSelectionEvent.fire(new CanvasClearSelectionEvent(canvasHandler));
+            selectionControl.clearSelection();
+
             if (selectedItems != null && !selectedItems.isEmpty()) {
                 // Execute the commands.
                 final CommandResult<CanvasViolation> result =
                         sessionCommandManager.execute(canvasHandler,
-                                                      canvasCommandFactory
-                                                              .delete(selectedItems.stream()
-                                                                              .map(uuid -> canvasHandler.getGraphIndex().get(uuid))
-                                                                              .collect(Collectors.toList())));
+                                                      canvasCommandFactory.delete(selectedItems.stream()
+                                                                                          .map(uuid -> canvasHandler.getGraphIndex().get(uuid))
+                                                                                          .filter(Objects::nonNull)
+                                                                                          .collect(Collectors.toList())));
+
                 // Check the results.
                 if (!CommandUtils.isError(result)) {
                     callback.onSuccess();
@@ -109,63 +146,38 @@ public class DeleteSelectionSessionCommand extends AbstractClientSessionCommand<
             } else {
                 callback.onError((V) new ClientRuntimeError("Cannot delete element, no element selected on canvas"));
             }
-            selectionControl.clearSelection();
-            clearSelectionEvent.fire(new CanvasClearSelectionEvent(getCanvasHandler()));
         }
     }
 
-    void onKeyDownEvent(final KeyboardEvent.Key... keys) {
-        if (KeysMatcher.doKeysMatch(keys,
-                                    KeyboardEvent.Key.DELETE)) {
-            DeleteSelectionSessionCommand.this.execute(new Callback<ClientRuntimeError>() {
-                @Override
-                public void onSuccess() {
-                    // Nothing to do.
-                }
-
-                @Override
-                public void onError(final ClientRuntimeError error) {
-                    LOGGER.log(Level.SEVERE,
-                               "Error while trying to delete selected items. Message=[" + error.toString() + "]",
-                               error.getThrowable());
-                }
-            });
+    protected void onKeyDownEvent(final KeyboardEvent.Key... keys) {
+        if (isEnabled()) {
+            handleDelete(keys);
         }
     }
 
-    void onCanvasSelectionEvent(final @Observes CanvasSelectionEvent event) {
-        checkNotNull("event",
-                     event);
-        handleCanvasSelectionEvent(event);
+    private void handleDelete(final KeyboardEvent.Key... keys) {
+        if (doKeysMatch(keys,
+                        KeyboardEvent.Key.DELETE)) {
+            this.execute();
+        }
     }
 
-    void onCanvasClearSelectionEvent(final @Observes CanvasClearSelectionEvent event) {
-        checkNotNull("event",
-                     event);
-        handleCanvasClearSelectionEvent(event);
-    }
-
-    private void handleCanvasSelectionEvent(final CanvasSelectionEvent event) {
-        if (checkEventContext(event)) {
+    @Override
+    protected void handleCanvasSelectionEvent(final CanvasSelectionEvent event) {
+        if (event.getIdentifiers().isEmpty() || onlyCanvasRootSelected(event)) {
+            enable(false);
+        } else {
             enable(true);
         }
     }
 
-    private void handleCanvasClearSelectionEvent(final CanvasClearSelectionEvent event) {
-        if (checkEventContext(event)) {
-            enable(false);
-        }
+    @Override
+    protected void handleCanvasClearSelectionEvent(final CanvasClearSelectionEvent event) {
+        enable(false);
     }
 
-    private void enable(boolean enable) {
-        setEnabled(enable);
-        fire();
-    }
-
-    private boolean checkEventContext(final AbstractCanvasHandlerEvent canvasHandlerEvent) {
-        final CanvasHandler _canvasHandler = canvasHandlerEvent.getCanvasHandler();
-        return null != getSession() &&
-                getSession().getCanvasHandler() != null
-                && getSession().getCanvasHandler().equals(_canvasHandler);
+    @Override
+    protected void handleCanvasElementsClearEvent(final CanvasElementsClearEvent event) {
+        enable(false);
     }
 }
