@@ -24,7 +24,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
 import org.kie.workbench.common.stunner.core.command.Command;
-import org.kie.workbench.common.stunner.core.command.CompositeCommand;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
@@ -32,16 +32,23 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandManager;
 import org.kie.workbench.common.stunner.core.graph.command.impl.GraphCommandFactory;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
 import org.kie.workbench.common.stunner.core.graph.processing.index.GraphIndexBuilder;
+import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionId;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class BPMNGraphFactoryImplTest {
@@ -62,7 +69,10 @@ public class BPMNGraphFactoryImplTest {
     private BPMNGraphFactoryImpl tested;
 
     @Before
+    @SuppressWarnings("unchecked")
     public void init() {
+        Index index = mock(Index.class);
+        when(indexBuilder.build(any(Graph.class))).thenReturn(index);
         tested = new BPMNGraphFactoryImpl(definitionManager,
                                           factoryManager,
                                           ruleManager,
@@ -83,9 +93,9 @@ public class BPMNGraphFactoryImplTest {
         final Node diagramNode = mock(Node.class);
         final Node startEventNode = mock(Node.class);
         when(factoryManager.newElement(anyString(),
-                                       eq(BPMNDiagramImpl.class))).thenReturn(diagramNode);
+                                       eq(getDefinitionId(BPMNDiagramImpl.class)))).thenReturn(diagramNode);
         when(factoryManager.newElement(anyString(),
-                                       eq(StartNoneEvent.class))).thenReturn(startEventNode);
+                                       eq(getDefinitionId(StartNoneEvent.class)))).thenReturn(startEventNode);
         final Graph<DefinitionSet, Node> graph = tested.build("uuid1",
                                                               "defSetId");
         assertNotNull(graph);
@@ -97,18 +107,13 @@ public class BPMNGraphFactoryImplTest {
         final ArgumentCaptor<Command> commandCaptor = ArgumentCaptor.forClass(Command.class);
         verify(graphCommandFactory,
                times(1)).addNode(eq(diagramNode));
-        verify(graphCommandFactory,
-               times(1)).addChildNode(eq(diagramNode),
-                                      eq(startEventNode),
-                                      eq(BPMNGraphFactoryImpl.START_X),
-                                      eq(BPMNGraphFactoryImpl.START_Y));
         verify(graphCommandManager,
                times(1)).execute(any(GraphCommandExecutionContext.class),
                                  commandCaptor.capture());
         final Command command = commandCaptor.getValue();
         assertTrue(command instanceof CompositeCommand);
         final CompositeCommand compositeCommand = (CompositeCommand) command;
-        assertEquals(2,
+        assertEquals(1,
                      compositeCommand.size());
     }
 }
