@@ -75,10 +75,13 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
             "System.out.println(\"`&(^*&^(\\n\\r\");\n" +
             "Object o = kcontext.getVariable(\"hello_world\");";
 
+    private static final String SLA_DUE_DATE = "12/25/1983";
+
     public EmbeddedSubProcessTest() throws Exception {
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -94,11 +97,13 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              EMPTY_VALUE,
                                              SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                              EMPTY_VALUE,
-                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertSubProcessProcessData(topLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME_JAVA = "Embedded process01 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_JAVA = "Embedded process01 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -107,9 +112,9 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
         final String SUB_PROCESS_NAME_MVEL = "Embedded process03 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_MVEL = "Embedded process03 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
 
-        final String SUB_PROCESS_VARIABLES_JAVA = "subVar01:String";
-        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar02:String";
-        final String SUB_PROCESS_VARIABLES_MVEL = "subVar03:String";
+        final String SUB_PROCESS_VARIABLES_JAVA = "subVar01:String:false";
+        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar02:String:false";
+        final String SUB_PROCESS_VARIABLES_MVEL = "subVar03:String:false";
 
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -125,7 +130,8 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              SUBPROCESS_ON_ENTRY_ACTION_JAVA,
                                              SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                              SUBPROCESS_ON_EXIT_ACTION_JAVA,
-                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertSubProcessProcessData(topLevelSubProcessJava.getProcessData(), SUB_PROCESS_VARIABLES_JAVA);
 
         EmbeddedSubprocess topLevelSubProcessJavascript = getSubProcessNodeById(diagram,
@@ -139,7 +145,8 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              SUBPROCESS_ON_ENTRY_ACTION_JAVASCRIPT,
                                              SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
                                              SUBPROCESS_ON_EXIT_ACTION_JAVASCRIPT,
-                                             SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertSubProcessProcessData(topLevelSubProcessJavascript.getProcessData(), SUB_PROCESS_VARIABLES_JAVASCRIPT);
 
         EmbeddedSubprocess topLevelSubProcessMVEL = getSubProcessNodeById(diagram,
@@ -153,11 +160,13 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              SUBPROCESS_ON_ENTRY_ACTION_MVEL,
                                              SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
                                              SUBPROCESS_ON_EXIT_ACTION_MVEL,
-                                             SUBPROCESS_SCRIPT_MVEL_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertSubProcessProcessData(topLevelSubProcessMVEL.getProcessData(), SUB_PROCESS_VARIABLES_MVEL);
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Sub-process07";
 
@@ -175,11 +184,13 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              EMPTY_VALUE,
                                              SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                              EMPTY_VALUE,
-                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertSubProcessProcessData(topLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -195,11 +206,13 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              EMPTY_VALUE,
                                              SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                              EMPTY_VALUE,
-                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertSubProcessProcessData(subProcessLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME_JAVA = "Embedded process04 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_JAVA = "Embedded process04 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -208,9 +221,9 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
         final String SUB_PROCESS_NAME_MVEL = "Embedded process06 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_MVEL = "Embedded process06 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
 
-        final String SUB_PROCESS_VARIABLES_JAVA = "subVar04:String";
-        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar05:String";
-        final String SUB_PROCESS_VARIABLES_MVEL = "subVar06:String";
+        final String SUB_PROCESS_VARIABLES_JAVA = "subVar04:String:false";
+        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar05:String:false";
+        final String SUB_PROCESS_VARIABLES_MVEL = "subVar06:String:false";
 
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -226,7 +239,8 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              SUBPROCESS_ON_ENTRY_ACTION_JAVA,
                                              SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                              SUBPROCESS_ON_EXIT_ACTION_JAVA,
-                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertSubProcessProcessData(subProcessLevelSubProcessJava.getProcessData(), SUB_PROCESS_VARIABLES_JAVA);
 
         EmbeddedSubprocess subProcessLevelSubProcessJavascript = getSubProcessNodeById(diagram,
@@ -240,7 +254,8 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              SUBPROCESS_ON_ENTRY_ACTION_JAVASCRIPT,
                                              SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
                                              SUBPROCESS_ON_EXIT_ACTION_JAVASCRIPT,
-                                             SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertSubProcessProcessData(subProcessLevelSubProcessJavascript.getProcessData(), SUB_PROCESS_VARIABLES_JAVASCRIPT);
 
         EmbeddedSubprocess subProcessLevelSubProcessMVEL = getSubProcessNodeById(diagram,
@@ -254,11 +269,13 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              SUBPROCESS_ON_ENTRY_ACTION_MVEL,
                                              SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
                                              SUBPROCESS_ON_EXIT_ACTION_MVEL,
-                                             SUBPROCESS_SCRIPT_MVEL_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertSubProcessProcessData(subProcessLevelSubProcessMVEL.getProcessData(), SUB_PROCESS_VARIABLES_MVEL);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Sub-process08";
 
@@ -276,7 +293,8 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                              EMPTY_VALUE,
                                              SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                              EMPTY_VALUE,
-                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                             SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertSubProcessProcessData(subProcessLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
@@ -329,9 +347,12 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
                                                       String onEntryActionScriptValue,
                                                       String onEntryActionScriptLanguage,
                                                       String onExitActionScriptValue,
-                                                      String onExitActionScriptLanguage) {
+                                                      String onExitActionScriptLanguage,
+                                                      String slaDueDate) {
         assertThat(executionSet).isNotNull();
+
         assertThat(executionSet.getIsAsync()).isNotNull();
+        assertThat(executionSet.getSlaDueDate()).isNotNull();
 
         assertThat(executionSet.getOnEntryAction()).isNotNull();
         assertThat(executionSet.getOnExitAction()).isNotNull();
@@ -347,6 +368,7 @@ public class EmbeddedSubProcessTest extends SubProcessTest<EmbeddedSubprocess> {
         assertThat(onExitScriptTypeValues.get(0)).isNotNull();
 
         assertThat(executionSet.getIsAsync().getValue()).isEqualTo(isAsync);
+        assertThat(executionSet.getSlaDueDate().getValue()).isEqualTo(slaDueDate);
 
         assertThat(onEntryScriptTypeValues.get(0).getScript()).isEqualTo(onEntryActionScriptValue);
         assertThat(onEntryScriptTypeValues.get(0).getLanguage()).isEqualTo(onEntryActionScriptLanguage);
