@@ -80,10 +80,13 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
             "System.out.println(\"`&(^*&^(\\n\\r\");\n" +
             "Object o = kcontext.getVariable(\"hello_world\");";
 
+    private static final String SLA_DUE_DATE = "12/25/1983";
+
     public ReusableSubProcessTest() throws Exception {
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -102,11 +105,13 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              EMPTY_VALUE,
                                              TASK_SCRIPT_JAVA_LANGUAGE,
                                              EMPTY_VALUE,
-                                             TASK_SCRIPT_JAVA_LANGUAGE);
+                                             TASK_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertDataIOSet(topLevelSubProcess.getDataIOSet(), DEFAULT_SUB_PROCESS_DATA_INPUT_OUTPUT);
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME = "Reusable process01 name ~!@#$%^&*()_+`-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION = "Reusable process01 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -130,7 +135,8 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_JAVA,
                                              TASK_SCRIPT_JAVA_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_JAVA,
-                                             TASK_SCRIPT_JAVA_LANGUAGE);
+                                             TASK_SCRIPT_JAVA_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertDataIOSet(topLevelSubProcessJava.getDataIOSet(), SUB_PROCESS_DATA_INPUT_OUTPUT);
 
         ReusableSubprocess topLevelSubProcessJavascript = getSubProcessNodeById(diagram,
@@ -147,7 +153,8 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_JAVASCRIPT,
                                              TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_JAVASCRIPT,
-                                             TASK_SCRIPT_JAVASCRIPT_LANGUAGE);
+                                             TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertDataIOSet(topLevelSubProcessJavascript.getDataIOSet(), SUB_PROCESS_DATA_INPUT_OUTPUT);
 
         ReusableSubprocess topLevelSubProcessMVEL = getSubProcessNodeById(diagram,
@@ -164,11 +171,13 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_MVEL,
                                              TASK_SCRIPT_MVEL_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_MVEL,
-                                             TASK_SCRIPT_MVEL_LANGUAGE);
+                                             TASK_SCRIPT_MVEL_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertDataIOSet(topLevelSubProcessMVEL.getDataIOSet(), SUB_PROCESS_DATA_INPUT_OUTPUT);
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Sub-process";
 
@@ -189,11 +198,13 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_JAVA,
                                              TASK_SCRIPT_JAVA_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_JAVA,
-                                             TASK_SCRIPT_JAVA_LANGUAGE);
+                                             TASK_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertDataIOSet(topLevelSubProcessJava.getDataIOSet(), DEFAULT_SUB_PROCESS_DATA_INPUT_OUTPUT);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -212,11 +223,13 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              EMPTY_VALUE,
                                              TASK_SCRIPT_JAVA_LANGUAGE,
                                              EMPTY_VALUE,
-                                             TASK_SCRIPT_JAVA_LANGUAGE);
+                                             TASK_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertDataIOSet(subProcessLevelSubProcess.getDataIOSet(), DEFAULT_SUB_PROCESS_DATA_INPUT_OUTPUT);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME = "Reusable process03 name ~!@#$%^&*()_+`-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION = "Reusable process03 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -240,7 +253,8 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_JAVA,
                                              TASK_SCRIPT_JAVA_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_JAVA,
-                                             TASK_SCRIPT_JAVA_LANGUAGE);
+                                             TASK_SCRIPT_JAVA_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertDataIOSet(subProcessLevelSubProcessJava.getDataIOSet(), SUB_PROCESS_DATA_INPUT_OUTPUT);
 
         ReusableSubprocess subProcessLevelSubProcessJavascript = getSubProcessNodeById(diagram,
@@ -257,7 +271,8 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_JAVASCRIPT,
                                              TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_JAVASCRIPT,
-                                             TASK_SCRIPT_JAVASCRIPT_LANGUAGE);
+                                             TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertDataIOSet(subProcessLevelSubProcessJavascript.getDataIOSet(), SUB_PROCESS_DATA_INPUT_OUTPUT);
 
         ReusableSubprocess subProcessLevelSubProcessMVEL = getSubProcessNodeById(diagram,
@@ -274,11 +289,13 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_MVEL,
                                              TASK_SCRIPT_MVEL_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_MVEL,
-                                             TASK_SCRIPT_MVEL_LANGUAGE);
+                                             TASK_SCRIPT_MVEL_LANGUAGE,
+                                             SLA_DUE_DATE);
         assertDataIOSet(subProcessLevelSubProcessMVEL.getDataIOSet(), SUB_PROCESS_DATA_INPUT_OUTPUT);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Sub-process";
 
@@ -299,7 +316,8 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                              TASK_ON_ENTRY_ACTION_JAVA,
                                              TASK_SCRIPT_JAVA_LANGUAGE,
                                              TASK_ON_EXIT_ACTION_JAVA,
-                                             TASK_SCRIPT_JAVA_LANGUAGE);
+                                             TASK_SCRIPT_JAVA_LANGUAGE,
+                                             EMPTY_VALUE);
         assertDataIOSet(subProcessLevelSubProcessJava.getDataIOSet(), DEFAULT_SUB_PROCESS_DATA_INPUT_OUTPUT);
     }
 
@@ -367,12 +385,14 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
                                                       String onEntryActionScriptValue,
                                                       String onEntryActionScriptLanguage,
                                                       String onExitActionScriptValue,
-                                                      String onExitActionScriptLanguage) {
+                                                      String onExitActionScriptLanguage,
+                                                      String slaDueDate) {
         assertThat(executionSet).isNotNull();
         assertThat(executionSet.getCalledElement()).isNotNull();
         assertThat(executionSet.getIndependent()).isNotNull();
         assertThat(executionSet.getIsAsync()).isNotNull();
         assertThat(executionSet.getWaitForCompletion()).isNotNull();
+        assertThat(executionSet.getSlaDueDate()).isNotNull();
 
         assertThat(executionSet.getOnEntryAction()).isNotNull();
         assertThat(executionSet.getOnExitAction()).isNotNull();
@@ -391,6 +411,7 @@ public class ReusableSubProcessTest extends SubProcessTest<ReusableSubprocess> {
         assertThat(executionSet.getIndependent().getValue()).isEqualTo(independent);
         assertThat(executionSet.getIsAsync().getValue()).isEqualTo(isAsync);
         assertThat(executionSet.getWaitForCompletion().getValue()).isEqualTo(waitForCompletion);
+        assertThat(executionSet.getSlaDueDate().getValue()).contains(slaDueDate);
 
         assertThat(onEntryScriptTypeValues.get(0).getScript()).isEqualTo(onEntryActionScriptValue);
         assertThat(onEntryScriptTypeValues.get(0).getLanguage()).isEqualTo(onEntryActionScriptLanguage);
