@@ -25,12 +25,16 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.client.forms.util.ListBoxValues;
-import org.kie.workbench.common.stunner.bpmn.client.forms.util.StringUtils;
+import org.kie.workbench.common.stunner.core.util.StringUtils;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Spy;
 
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class ComboBoxTest {
@@ -192,7 +196,7 @@ public class ComboBoxTest {
                       processVarConstantPrompt,
                       processVarConstantPlaceholder);
         String constant = "a constant";
-        String quotedConstant = StringUtils.createQuotedConstant(constant);
+        String quotedConstant = StringUtils.createQuotedConstantOptionalNumeric(constant);
         when(listBoxValues.isCustomValue(quotedConstant)).thenReturn(true);
         when(listBoxValues.getValueForDisplayValue(quotedConstant)).thenReturn(quotedConstant);
         comboBox.listBoxValueChanged(quotedConstant);
@@ -213,7 +217,7 @@ public class ComboBoxTest {
                       processVarConstantPrompt,
                       processVarConstantPlaceholder);
         String constant = "\"hello\"";
-        String quotedConstant = StringUtils.createQuotedConstant(constant);
+        String quotedConstant = StringUtils.createQuotedConstantOptionalNumeric(constant);
         when(listBoxValues.isCustomValue(quotedConstant)).thenReturn(true);
         when(listBoxValues.getValueForDisplayValue(quotedConstant)).thenReturn(quotedConstant);
         comboBox.listBoxValueChanged(quotedConstant);
@@ -234,7 +238,7 @@ public class ComboBoxTest {
                       processVarConstantPrompt,
                       processVarConstantPlaceholder);
         String constant = "greeting={\"hello\"}";
-        String quotedConstant = StringUtils.createQuotedConstant(constant);
+        String quotedConstant = StringUtils.createQuotedConstantOptionalNumeric(constant);
         when(listBoxValues.isCustomValue(quotedConstant)).thenReturn(true);
         when(listBoxValues.getValueForDisplayValue(quotedConstant)).thenReturn(quotedConstant);
         comboBox.listBoxValueChanged(quotedConstant);
@@ -353,7 +357,7 @@ public class ComboBoxTest {
                       processVarConstantPrompt,
                       processVarConstantPlaceholder);
         String value = "something new";
-        String quotedValue = StringUtils.createQuotedConstant(value);
+        String quotedValue = StringUtils.createQuotedConstantOptionalNumeric(value);
         when(listBoxValues.getNonCustomValueForUserString(value)).thenReturn(null);
         when(comboBox.addCustomValueToListBoxValues(value,
                                                     "")).thenReturn(quotedValue);
@@ -368,4 +372,18 @@ public class ComboBoxTest {
         verify(view).setTextBoxVisible(false);
         verify(view).setListBoxVisible(true);
     }
+
+    @Test
+    public void testSetReadOnlyTrue() {
+        comboBox.setReadOnly(true);
+        verify(view,
+               times(1)).setReadOnly(true);
+    }
+
+    @Test
+    public void testSetReadOnlyFalse() {
+        comboBox.setReadOnly(false);
+        verify(view,
+               times(1)).setReadOnly(false);
+    }
 }
