@@ -15,6 +15,8 @@
  */
 package org.kie.workbench.common.stunner.cm.definition.property.task;
 
+import java.util.Objects;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
@@ -27,9 +29,12 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.SkipFormField;
 import org.kie.workbench.common.forms.adf.definitions.annotations.field.selector.SelectorDataProvider;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.type.ListBoxFieldType;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.type.TextAreaFieldType;
+import org.kie.workbench.common.stunner.bpmn.definition.property.general.SLADueDate;
 import org.kie.workbench.common.stunner.bpmn.definition.property.subProcess.IsCase;
+import org.kie.workbench.common.stunner.bpmn.definition.property.task.AbortParent;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.AdHocAutostart;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.BaseReusableSubprocessTaskExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.task.BaseSubprocessTaskExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.CalledElement;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.Independent;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.IsAsync;
@@ -57,12 +62,13 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
         startElement = "calledElement"
 )
 public class ProcessReusableSubprocessTaskExecutionSet
+        extends BaseSubprocessTaskExecutionSet
         implements BaseReusableSubprocessTaskExecutionSet {
 
     @Property
     @SelectorDataProvider(
             type = SelectorDataProvider.ProviderType.REMOTE,
-            className = "org.kie.workbench.common.stunner.bpmn.backend.dataproviders.CalledElementFormProvider")
+            className = "org.kie.workbench.common.stunner.cm.backend.dataproviders.CaseCalledElementFormProvider")
     @FormField(
             type = ListBoxFieldType.class
     )
@@ -86,14 +92,14 @@ public class ProcessReusableSubprocessTaskExecutionSet
             afterElement = "independent"
     )
     @Valid
-    protected WaitForCompletion waitForCompletion;
+    protected AbortParent abortParent;
 
     @Property
     @FormField(
-            afterElement = "waitForCompletion"
+            afterElement = "abortParent"
     )
     @Valid
-    protected IsAsync isAsync;
+    protected WaitForCompletion waitForCompletion;
 
     @Property
     @FormField(afterElement = "isAsync")
@@ -187,6 +193,7 @@ public class ProcessReusableSubprocessTaskExecutionSet
         this(new CalledElement(),
              new IsCase(false),
              new Independent(),
+             new AbortParent(),
              new WaitForCompletion(),
              new IsAsync(),
              new AdHocAutostart(),
@@ -198,12 +205,14 @@ public class ProcessReusableSubprocessTaskExecutionSet
              new MultipleInstanceDataOutput(),
              new MultipleInstanceCompletionCondition(),
              new OnEntryAction(new ScriptTypeListValue().addValue(new ScriptTypeValue("java", ""))),
-             new OnExitAction(new ScriptTypeListValue().addValue(new ScriptTypeValue("java", ""))));
+             new OnExitAction(new ScriptTypeListValue().addValue(new ScriptTypeValue("java", ""))),
+             new SLADueDate());
     }
 
     public ProcessReusableSubprocessTaskExecutionSet(final @MapsTo("calledElement") CalledElement calledElement,
                                                      final @MapsTo("isCase") IsCase isCase,
                                                      final @MapsTo("independent") Independent independent,
+                                                     final @MapsTo("abortParent") AbortParent abortParent,
                                                      final @MapsTo("waitForCompletion") WaitForCompletion waitForCompletion,
                                                      final @MapsTo("isAsync") IsAsync isAsync,
                                                      final @MapsTo("adHocAutostart") AdHocAutostart adHocAutostart,
@@ -215,12 +224,14 @@ public class ProcessReusableSubprocessTaskExecutionSet
                                                      final @MapsTo("multipleInstanceDataOutput") MultipleInstanceDataOutput multipleInstanceDataOutput,
                                                      final @MapsTo("multipleInstanceCompletionCondition") MultipleInstanceCompletionCondition multipleInstanceCompletionCondition,
                                                      final @MapsTo("onEntryAction") OnEntryAction onEntryAction,
-                                                     final @MapsTo("onExitAction") OnExitAction onExitAction) {
+                                                     final @MapsTo("onExitAction") OnExitAction onExitAction,
+                                                     final @MapsTo("slaDueDate") SLADueDate slaDueDate) {
+        super(isAsync, slaDueDate);
         this.calledElement = calledElement;
         this.isCase = isCase;
         this.independent = independent;
+        this.abortParent = abortParent;
         this.waitForCompletion = waitForCompletion;
-        this.isAsync = isAsync;
         this.adHocAutostart = adHocAutostart;
         this.isMultipleInstance = isMultipleInstance;
         this.multipleInstanceExecutionMode = multipleInstanceExecutionMode;
@@ -263,6 +274,16 @@ public class ProcessReusableSubprocessTaskExecutionSet
         this.independent = independent;
     }
 
+    @Override
+    public AbortParent getAbortParent() {
+        return abortParent;
+    }
+
+    @Override
+    public void setAbortParent(final AbortParent abortParent) {
+        this.abortParent = abortParent;
+    }
+
     @Override
     public WaitForCompletion getWaitForCompletion() {
         return waitForCompletion;
@@ -273,16 +294,6 @@ public class ProcessReusableSubprocessTaskExecutionSet
         this.waitForCompletion = waitForCompletion;
     }
 
-    @Override
-    public IsAsync getIsAsync() {
-        return isAsync;
-    }
-
-    @Override
-    public void setIsAsync(IsAsync isAsync) {
-        this.isAsync = isAsync;
-    }
-
     @Override
     public AdHocAutostart getAdHocAutostart() {
         return adHocAutostart;
@@ -385,43 +396,48 @@ public class ProcessReusableSubprocessTaskExecutionSet
 
     @Override
     public int hashCode() {
-        return HashUtil.combineHashCodes(calledElement.hashCode(),
-                                         isCase.hashCode(),
-                                         independent.hashCode(),
-                                         waitForCompletion.hashCode(),
-                                         isAsync.hashCode(),
-                                         adHocAutostart.hashCode(),
-                                         isMultipleInstance.hashCode(),
-                                         multipleInstanceExecutionMode.hashCode(),
-                                         multipleInstanceCollectionInput.hashCode(),
-                                         multipleInstanceDataInput.hashCode(),
-                                         multipleInstanceCollectionOutput.hashCode(),
-                                         multipleInstanceDataOutput.hashCode(),
-                                         multipleInstanceCompletionCondition.hashCode(),
-                                         onEntryAction.hashCode(),
-                                         onExitAction.hashCode());
+        return HashUtil.combineHashCodes(super.hashCode(),
+                                         Objects.hashCode(calledElement),
+                                         Objects.hashCode(isCase),
+                                         Objects.hashCode(independent),
+                                         Objects.hashCode(abortParent),
+                                         Objects.hashCode(waitForCompletion),
+                                         Objects.hashCode(adHocAutostart),
+                                         Objects.hashCode(isMultipleInstance),
+                                         Objects.hashCode(multipleInstanceExecutionMode),
+                                         Objects.hashCode(multipleInstanceCollectionInput),
+                                         Objects.hashCode(multipleInstanceDataInput),
+                                         Objects.hashCode(multipleInstanceCollectionOutput),
+                                         Objects.hashCode(multipleInstanceDataOutput),
+                                         Objects.hashCode(multipleInstanceCompletionCondition),
+                                         Objects.hashCode(onEntryAction),
+                                         Objects.hashCode(onExitAction));
     }
 
     @Override
     public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
         if (o instanceof ProcessReusableSubprocessTaskExecutionSet) {
             ProcessReusableSubprocessTaskExecutionSet other = (ProcessReusableSubprocessTaskExecutionSet) o;
-            return calledElement.equals(other.calledElement) &&
-                    isCase.equals(other.isCase) &&
-                    independent.equals(other.independent) &&
-                    waitForCompletion.equals(other.waitForCompletion) &&
-                    isAsync.equals(other.isAsync) &&
-                    adHocAutostart.equals(other.adHocAutostart) &&
-                    isMultipleInstance.equals(other.isMultipleInstance) &&
-                    multipleInstanceExecutionMode.equals(other.multipleInstanceExecutionMode) &&
-                    multipleInstanceCollectionInput.equals(other.multipleInstanceCollectionInput) &&
-                    multipleInstanceDataInput.equals(other.multipleInstanceDataInput) &&
-                    multipleInstanceCollectionOutput.equals(other.multipleInstanceCollectionOutput) &&
-                    multipleInstanceDataOutput.equals(other.multipleInstanceDataOutput) &&
-                    multipleInstanceCompletionCondition.equals(other.multipleInstanceCompletionCondition) &&
-                    onEntryAction.equals(other.onEntryAction) &&
-                    onExitAction.equals(other.onExitAction);
+            return super.equals(other) &&
+                    Objects.equals(calledElement, other.calledElement) &&
+                    Objects.equals(isCase, other.isCase) &&
+                    Objects.equals(independent, other.independent) &&
+                    Objects.equals(abortParent, other.abortParent) &&
+                    Objects.equals(waitForCompletion, other.waitForCompletion) &&
+                    Objects.equals(adHocAutostart, other.adHocAutostart) &&
+                    Objects.equals(isMultipleInstance, other.isMultipleInstance) &&
+                    Objects.equals(multipleInstanceExecutionMode, other.multipleInstanceExecutionMode) &&
+                    Objects.equals(multipleInstanceCollectionInput, other.multipleInstanceCollectionInput) &&
+                    Objects.equals(multipleInstanceDataInput, other.multipleInstanceDataInput) &&
+                    Objects.equals(multipleInstanceCollectionOutput, other.multipleInstanceCollectionOutput) &&
+                    Objects.equals(multipleInstanceDataOutput, other.multipleInstanceDataOutput) &&
+                    Objects.equals(multipleInstanceCompletionCondition, other.multipleInstanceCompletionCondition) &&
+                    Objects.equals(onEntryAction, other.onEntryAction) &&
+                    Objects.equals(onExitAction, other.onExitAction);
         }
         return false;
     }
-}
+}
\ No newline at end of file
