@@ -23,6 +23,9 @@ import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagram;
+import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
+import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.factory.BPMNGraphFactory;
 import org.kie.workbench.common.stunner.bpmn.factory.BPMNGraphFactoryImpl;
 import org.kie.workbench.common.stunner.cm.definition.AdHocSubprocess;
@@ -46,12 +49,21 @@ import org.kie.workbench.common.stunner.core.graph.processing.index.GraphIndexBu
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.util.UUID;
 
+import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionId;
+
 /**
  * The custom factory for Case Management graphs.
  */
 @Dependent
 public class CaseManagementGraphFactoryImpl extends AbstractGraphFactory implements CaseManagementGraphFactory {
 
+    public static String START_EVENT_ID = getDefinitionId(StartNoneEvent.class);
+    public static String SUBPROCESS_ID = getDefinitionId(AdHocSubprocess.class);
+    public static String END_EVENT_ID = getDefinitionId(EndNoneEvent.class);
+    public static String SEQ_FLOW_ID = getDefinitionId(SequenceFlow.class);
+    private static final double CONNECTION_LOCATION_X = 475d;
+    private static final double CONNECTION_LOCATION_Y = 475d;
+
     private final DefinitionManager definitionManager;
     private final RuleManager ruleManager;
     private final GraphIndexBuilder<?> indexBuilder;
@@ -129,18 +141,10 @@ public class CaseManagementGraphFactoryImpl extends AbstractGraphFactory impleme
 
     @SuppressWarnings("unchecked")
     protected List<Command> buildInitialisationCommands() {
-
         final List<Command> commands = new ArrayList<>();
-
         final Node<Definition<CaseManagementDiagram>, Edge> diagramNode =
-                (Node<Definition<CaseManagementDiagram>, Edge>) factoryManager.newElement(UUID.uuid(), diagramType);
-
-        final Node<Definition<AdHocSubprocess>, Edge> stageNode =
-                (Node<Definition<AdHocSubprocess>, Edge>) factoryManager.newElement(UUID.uuid(), AdHocSubprocess.class);
-
+                (Node<Definition<CaseManagementDiagram>, Edge>) factoryManager.newElement(UUID.uuid(), getDefinitionId(diagramType));
         commands.add(graphCommandFactory.addNode(diagramNode));
-        commands.add(graphCommandFactory.addChildNode(diagramNode, stageNode));
-
         return commands;
     }
 
