@@ -55,7 +55,6 @@ import org.uberfire.client.workbench.type.ClientResourceType;
 import org.uberfire.client.workbench.widgets.multipage.Page;
 import org.uberfire.ext.editor.commons.client.BaseEditor;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
-import org.uberfire.ext.editor.commons.client.file.popups.DeletePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
@@ -65,6 +64,7 @@ import org.uberfire.ext.editor.commons.client.validation.ValidatorWithReasonCall
 import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.mvp.Command;
+import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
@@ -104,8 +104,6 @@ public abstract class KieEditor<T>
     @Inject
     protected SavePopUpPresenter savePopUpPresenter;
     @Inject
-    protected DeletePopUpPresenter deletePopUpPresenter;
-    @Inject
     protected RenamePopUpPresenter renamePopUpPresenter;
     @Inject
     protected CopyPopUpPresenter copyPopUpPresenter;
@@ -288,7 +286,11 @@ public abstract class KieEditor<T>
                                 () -> overviewWidget.refresh(versionRecordManager.getVersion()));
     }
 
-    private void resetMetadata(final Overview overview) {
+    protected void resetEditorPagesOnLoadError(final Overview overview) {
+        resetEditorPages(overview);
+    }
+
+    protected void resetMetadata(final Overview overview) {
 
         this.metadata = overview.getMetadata();
 
@@ -335,7 +337,11 @@ public abstract class KieEditor<T>
     }
 
     protected void addSave(final FileMenuBuilder fileMenuBuilder) {
-        fileMenuBuilder.addSave(versionRecordManager.newSaveMenuItem(getSaveActionCommand()));
+        final ParameterizedCommand<Boolean> onSave = withComments -> {
+            saveWithComments = withComments;
+            saveAction();
+        };
+        fileMenuBuilder.addSave(versionRecordManager.newSaveMenuItem(onSave));
     }
 
     protected void addCopy(final FileMenuBuilder fileMenuBuilder) {
@@ -470,12 +476,19 @@ public abstract class KieEditor<T>
 
     @Override
     protected void save() {
-        savePopUpPresenter.show(versionRecordManager.getCurrentPath(),
-                                (commitMessage) -> {
-                                    baseView.showSaving();
-                                    save(commitMessage);
-                                    concurrentUpdateSessionInfo = null;
-                                });
+        ParameterizedCommand<String> command = (commitMessage) -> {
+            baseView.showSaving();
+            save(commitMessage);
+            concurrentUpdateSessionInfo = null;
+        };
+
+        if (saveWithComments) {
+            savePopUpPresenter.show(versionRecordManager.getCurrentPath(),
+                                    command);
+        } else {
+            command.execute("");
+        }
+
         concurrentUpdateSessionInfo = null;
     }
 
@@ -523,6 +536,10 @@ public abstract class KieEditor<T>
     public void onEditTabUnselected() {
     }
 
+    public void addTabBarWidget(final IsWidget customWidget) {
+        kieView.addTabBarWidget(customWidget);
+    }
+
     //Handler for MayClose requests
     private interface MayCloseHandler {
 
